// Replication Codes for ROBOT ADOPTION AT GERMAN PLANTS by Liuchun Deng, Verena Plümpe, and Jens Stegmaier. 
// Published in Jahrbücher für Nationalökonomie und Statistik, 2023. https://doi.org/10.1515/jbnst-2022-0073
//------------------------------------------------------------------------------
version 16
clear all
set more off
set linesize 140
set maxvar 12000

//------------------------------------------------------------------------------
// SETUP 
//------------------------------------------------------------------------------
	capture mkdir " " 		/* insert path here */ 
	global main	= " " 		/* insert path here */ 

// Creating folder structure
	capture mkdir "${main}\orig"
	capture mkdir "${main}\prog"
	capture mkdir "${main}\data"
	capture mkdir "${main}\log"
	capture mkdir "${main}\results"
	capture mkdir "${main}\results\temp"

// Define globals
	global orig		= "${main}\orig"
	global data		= "${main}\data"
	global results 	= "${main}\results"
	global log    	= "${main}\log"
	global prog		= "${main}\prog"

// Set directory:
	cd "$results"
	
//------------------------------------------------------------------------------
// REPLICATION CODES
//------------------------------------------------------------------------------
// DATA PREPARATION
	do "$prog\01_IAB_preparation_waves.do"	// selection of variables 
	do "$prog\02_IAB_panel.do"				// generation of panel (2013-2019)
	do "$prog\03_clean.do"  				// cleaning of robot data
	do "$prog\04_impute_reshape.do" 		// reshaping robot data (wide to long format) 
	do "$prog\05_indicators.do" 			// construction of indicators for analysis 
	do "$prog\06_capstock_approx.do" 		// capital stock approximation 
	do "$prog\07_TFP_estimation.do"			// TFP estimation
	do "$prog\08_preparing_controls.do"		// prparing control variables

// 5 FACTS (output for chapter 2.2)
 	do "$prog\fact1.do" 	
	do "$prog\fact2.do" 	
	do "$prog\fact3.do" 	
	do "$prog\fact4.do" 	
	do "$prog\fact5.do" 	
	
// REGRESSIONS (output for chapter 3)
	do "$prog\regression_choice_explanatories.do" 	
	do "$prog\regression_crosssection.do" 		
	do "$prog\regression_panel.do" 		






