cap log close
local date: di %d date(c(current_date),"DMY")
log using $log\IAB_preparation_waves_`date'.log, replace
*------------------------------------------------------------------------------*
* Preparation of IAB Establishment Panel Survey Waves (2013-2019) 
*------------------------------------------------------------------------------*

*-------------------------------------------------------------------------------
* Wave 2013 
*-------------------------------------------------------------------------------
use "$orig\iab13ges.dta", clear
keep if quer2013=="Q"        // select cross-sectional format
gen year=2013
recode bula2013 (7=18) // fix regional classification
ren bula2013 	bula
ren hr2013q  	hrf_quer
ren u90b 		bran_n09
ren u27ges		ges_bes
ren u01ges12	empl_L1
ren grkl2013	plant_sizeclass
replace u18=0 if u17e==1	// fix investments 

ren u06a	 	x06a
ren u06b	 	x06b
ren u07 		business_type	
ren u08 		business_vol	
ren u09c 		business_vol_abroad	
ren u11	 		vorleis
ren u12b	 	need_staff	
ren u15proz 	dev_business_vol 		
ren u17a 		inv_geba	
ren u17b 		inv_edv	
ren u17c 		inv_prod	
ren u17d 		inv_verk	
ren u17e 		inv_kein	
ren u18 		invest	
ren u19 		invest_add 
ren u20 		tech_equip	
ren u21			inno1
ren u22			inno2
ren u23			inno3
ren u24	 		inno4
ren u25ba		inno_highcost	
ren u25bb		inno_highrisk	
ren u25bc		inno_nocredit	
ren u25be		inno_noqualstaff	
ren u25bg		inno_laws	
ren u27ber		bea_ber	
ren u27einf 	bea_einf		
ren u27uni		bea_uni	
ren u40 		bluecoll_wanted	
ren u48			tarif
ren u52 		wage_total	
ren u81a 		betrrat	
ren u87 		single	
ren u88b 		founded	
replace founded=999 if u88a==1	

gen owner=.		
replace owner =4 if u86a==1
replace owner =6 if u86a==3
replace owner =1 if u86b==2
replace owner =2 if u86b==1
replace owner =3 if u86b==3
replace owner =5 if u86b==4
replace owner =6 if u86b==5


keep idnum year hrf_quer quer* bula bran_n09 br19fb ges_bes tarif  /// 
	owner tech_equip inno* vorlei* inv* empl_* x06*  ///
	wage_total bluecoll_wanted bea* *business_vol* betrrat  need* founded plant_sizeclass single
compress
save "$data\iabbp_2013.dta", replace


*-------------------------------------------------------------------------------
* Wave 2014 
*-------------------------------------------------------------------------------
use "$orig\iab14ges.dta", clear
keep if quer2014=="Q"        // select cross-sectional format
gen year=2014
recode bula2014 (7=18) // fix regional classification
ren bula2014 	bula
ren hr2014q  	hrf_quer
ren v89b	 	bran_n09
ren v25ges		ges_bes
ren v01ges13	empl_L1
ren grkl2014	plant_sizeclass
replace v18=0 if v17e==1	// fix investments 

ren v06a	 	x06a
ren v06b	 	x06b
ren v08 		business_vol
ren v09c 		business_vol_abroad
ren v15proz 	dev_business_vol 
ren v11	 		vorleis		
ren	v12b 		need_staff	
ren	v13 		ertrlagv	
ren v17a 		inv_geba				
ren v17b 		inv_edv				
ren v17c 		inv_prod				
ren v17d 		inv_verk				
ren v17e 		inv_kein				
ren v19 		invest_add 		
ren	v18 		invest	
ren v20 		tech_equip
ren	v21	 		inno1		
ren	v22	 		inno2		
ren	v23	 		inno3		
ren	v24	 		inno4		
ren	v25ber		bea_ber	
ren	v25einf 	bea_einf		
ren v25uni		bea_uni
ren v36 		bluecoll_wanted
ren v73			tarif
ren v78 		wage_total
ren v79a 		betrrat	
ren v83 		single	
ren v87b 		founded	
replace founded=999 if v88a==1		
ren br19fb14	br19fb

*include 2014 questions on staffing problems:
ren v05a	x05a
ren v05b	x05b
ren v05c	x05c
ren v05d	x05d
ren v05e	x05e
ren v05f	x05f
ren v05g	x05g
ren v05h	x05h
ren v05i	x05i
ren v05j	x05j
ren v05k	x05k

gen owner=.		
replace owner =4 if v86a==1
replace owner =6 if v86a==3
replace owner =1 if v86b==2
replace owner =2 if v86b==1
replace owner =3 if v86b==3
replace owner =5 if v86b==4
replace owner =6 if v86b==5


keep idnum year hrf_quer quer* bula bran_n09 br19fb ges_bes tarif owner tech_equip inno* vorlei* inv* empl_* ///
	wage_total bluecoll_wanted bea* *business_vol* betrrat  founded plant_sizeclass single x05* x06*
compress
save "$data\iabbp_2014.dta", replace


*-------------------------------------------------------------------------------
* Wave 2015 
*-------------------------------------------------------------------------------
use "$orig\iab15ges.dta", clear
keep if quer2015=="Q"        // select cross-sectional format
gen year=2015
recode bula2015 (7=18) // fix regional classification
ren bula2015 	bula	   
ren hr2015q  	hrf_quer	   
ren w91b 		bran_n09	   
ren grkl2015	plant_sizeclass
ren w26ges		ges_bes
ren w01ges14	empl_L1
replace w17=0 if w16e==1 	// fix investments 

ren w05a	 	x06a
ren w05b	 	x06b
ren w07 		business_vol	
ren w08c 		business_vol_abroad
ren w10	 		vorleis		
ren w11b	 	need_staff	
ren w14proz 	dev_business_vol 		
ren w16a 		inv_geba			
ren w16b 		inv_edv			
ren w16c 		inv_prod			
ren w16d 		inv_verk			
ren w16e 		inv_kein			
ren w17 		invest		   
ren w18 		invest_add 		
ren w19 		tech_equip	
ren w20	 		inno1		
ren w21	 		inno2		
ren w22	 		inno3		
ren w23	 		inno4		
ren w24ba		inno_highcost	
ren w24bb		inno_highrisk	
ren w24bc		inno_nocredit	
ren w24be		inno_noqualstaff	
ren w24bg		inno_laws	
ren w26ber	 	bea_ber	
ren w26einf 	bea_einf	   	
ren w26uni	 	bea_uni	
ren w39 		bluecoll_wanted	
ren w61			tarif
ren w64 		wage_total	
ren w81 		betrrat	   
ren w88 		single	
ren w89b 		founded	   
replace founded=999 if w90a==1 		
ren br19fb15	br19fb

gen owner=.	   
replace owner =4 if w86a==1
replace owner =6 if w86a==3
replace owner =1 if w86b==2
replace owner =2 if w86b==1
replace owner =3 if w86b==3
replace owner =5 if w86b==4
replace owner =6 if w86b==5

tab w24a
tab w24a, nolabel
* replace missings in w24b with 0 if w24a is missing
tab  inno_highcost, nolabel
tab  inno_highrisk, nolabel
replace  inno_highcost=0 if  inno_highcost==-9 & w24a==2
replace  inno_highrisk=0 if  inno_highrisk==-9 & w24a==2
replace  inno_nocredit=0 if  inno_nocredit==-9 & w24a==2
replace  inno_noqualstaff=0 if  inno_noqualstaff==-9 & w24a==2
replace  inno_laws=0 if  inno_laws==-9 & w24a==2

* Minimum wage 2015
ren w66a minwage_w66a
ren w66b minwage_w66b

keep idnum year hrf_quer quer* bula bran_n09 br19fb ges_bes tarif owner tech_equip inno* vorlei* inv* empl_* ///
	wage_total bluecoll_wanted bea* *business_vol* betrrat need* founded plant_sizeclass single minwage_w66* x06*
compress
save "$data\iabbp_2015.dta", replace 


*-------------------------------------------------------------------------------
* Wave 2016 
*-------------------------------------------------------------------------------
use "$orig\iab16ges.dta", clear
keep if quer2016=="Q"        // select cross-sectional format
gen year=2016
recode bula2016 (7=18) // fix regional classification
ren bula2016 	bula
ren hr2016q  	hrf_quer
ren x89b 		bran_n09
ren grkl2016	plant_sizeclass
ren x26ges		ges_bes
ren x01ges15	empl_L1
replace x18=0 if x17e==1 // fix investments 

ren x06a 		x06a 
ren x06b 		x06b
ren x08 		business_vol	
ren x09c 		business_vol_abroad
ren x12	 		vorleis
ren x13b 		need_staff
ren x16proz 	dev_business_vol 		
ren x17a 		inv_geba	
ren x17b 		inv_edv	
ren x17c 		inv_prod	
ren x17d 		inv_verk	
ren x17e 		inv_kein	
ren x18 		invest	
ren x19 		invest_add 
ren x20 		tech_equip	
ren x21	 		inno1
ren x22	 		inno2
ren x23	 		inno3
ren x24	 		inno4
ren x26ber 		bea_ber	
ren x26einf 	bea_einf		
ren x26uni 		bea_uni	
ren x37 		bluecoll_wanted
ren x50			tarif
ren x53 		wage_total	
ren x78a 		betrrat	
ren x84			single
ren x87b 		founded
replace founded=999 if x87a==1
ren br19fb16	br19fb

gen owner=.		
replace owner =4 if x83a==1
replace owner =6 if x83a==3
replace owner =1 if x83b==2
replace owner =2 if x83b==1
replace owner =3 if x83b==3
replace owner =5 if x83b==4
replace owner =6 if x83b==5

* digitization 
ren x25a		digitization_x25a
ren x25b 		digitization_x25b
ren x25c 		digitization_x25c
replace digitization_x25a =. if digitization_x25a==-9 | digitization_x25a==-1
replace digitization_x25b =. if digitization_x25b==-9 | digitization_x25b==-1
replace digitization_x25c =. if digitization_x25c==-9 | digitization_x25c==-1


keep idnum year hrf_quer quer* bula bran_n09 br19fb ges_bes tarif owner tech_equip inno* vorlei* inv* empl_* x06* ///
	wage_total bluecoll_wanted bea* *business_vol* betrrat founded plant_sizeclass single digitization_x25* 
compress
save "$data\iabbp_2016.dta", replace



*-------------------------------------------------------------------------------
* Wave 2017 
*-------------------------------------------------------------------------------
use "$orig\iab17ges.dta", clear
keep if quer2017=="Q"        // select cross-sectional format
gen year=2017
recode bula2017 (7=18) // fix regional classification
ren bula2017 	bula
ren hr2017q  	hrf_quer
ren y90b 		bran_n09
ren grkl2017	plant_sizeclass
ren y30ges		ges_bes
ren y01ges16	empl_L1
replace y21=0 if y20e==1 	// fix investments

ren y08a 		x06a 
ren y08b 		x06b
ren y11 		business_vol
ren y12c 		business_vol_abroad
ren y15		 	vorleis
ren y16b		need_staff
ren y19proz 	dev_business_vol 
ren y20a 		inv_geba		
ren y20b 		inv_edv		
ren y20c 		inv_prod		
ren y20d 		inv_verk		
ren y20e 		inv_kein		
ren y21 		invest
ren y22 		invest_add 		
ren y23 		tech_equip
ren y24	 		inno1
ren y25	 		inno2
ren y26	 		inno3
ren y27	 		inno4
ren y28ba		inno_highcost
ren y28bb		inno_highrisk
ren y28bc		inno_nocredit
ren y28be		inno_noqualstaff
ren y28bg		inno_laws
ren y30ber 		bea_ber		
ren y30einf 	bea_einf		
ren y30uni 		bea_uni		
ren y41 		bluecoll_wanted
ren y52			tarif
ren y55 		wage_total
ren y79 		betrrat	
ren y86			single
ren y88b 		founded	
replace founded=999 if y88a==1		
ren br19fb17	br19fb

gen owner=.		
replace owner =4 if y84a==1
replace owner =6 if y84a==3
replace owner =1 if y84b==2
replace owner =2 if y84b==1
replace owner =3 if y84b==3
replace owner =5 if y84b==4
replace owner =6 if y84b==5

* robot CNC use
ren y77ga 		robot_cnc_y77ga
ren y77gb 		robot_cnc_y77gb
replace robot_cnc_y77ga=. if robot_cnc_y77ga==-9
replace robot_cnc_y77gb=. if robot_cnc_y77gb==-9

tab y28a
tab y28a, nolabel
* replace missings in y28b with 0 if y28a is missing
tab  inno_highcost, nolabel
tab  inno_highrisk, nolabel
replace  inno_highcost=0 if  inno_highcost==-9 & y28a==2
replace  inno_highrisk=0 if  inno_highrisk==-9 & y28a==2
replace  inno_nocredit=0 if  inno_nocredit==-9 & y28a==2
replace  inno_noqualstaff=0 if  inno_noqualstaff==-9 & y28a==2
replace  inno_laws=0 if  inno_laws==-9 & y28a==2

keep idnum year hrf_quer quer* bula bran_n09 br19fb ges_bes tarif owner tech_equip inno* vorlei* inv* empl_* x06* ///
	wage_total bluecoll_wanted bea* *business_vol* betrrat need* founded plant_sizeclass single robot*
compress
save "$data\iabbp_2017.dta", replace


*-------------------------------------------------------------------------------
* Wave 2018 
*-------------------------------------------------------------------------------
use "$orig\iab18ges.dta", clear
keep if quer2018=="Q"        // select cross-sectional format
gen year=2018
recode bula2018 (7=18) // fix regional classification			   
ren bula2018 	bula
ren hr2018q  	hrf_quer
ren z91b 		bran_n09
ren grkl2018	plant_sizeclass
ren z27ges		ges_bes
ren z01ges17	empl_L1
replace z20=0 if z19e==1 		// fix investments 

ren z08a 		x06a 
ren z08b 		x06b
ren z10 		business_vol	
ren z11c 		business_vol_abroad
ren z13	 		vorleis
ren z14b		need_staff	
ren z17proz 	dev_business_vol 		
ren z19a 		inv_geba	
ren z19b 		inv_edv	
ren z19c 		inv_prod	
ren z19d 		inv_verk	
ren z19e 		inv_kein	
ren z20 		invest	
ren z21 		invest_add 
ren z22 		tech_equip	
ren z23	 		inno1
ren z24	 		inno2
ren z25	 		inno3
ren z26	 		inno4
ren z27ber 		bea_ber	
ren z27einf 	bea_einf		
ren z27uni 		bea_uni	
ren z34 		bluecoll_wanted	
ren z50			tarif
ren z53 		wage_total	
ren z82 		betrrat	
ren z88			single
ren z89b 		founded	
replace founded=999 if z89a==1
ren br19fb18	br19fb

gen owner=.		
replace owner =4 if z86a==1
replace owner =6 if z86a==3
replace owner =1 if z86b==2
replace owner =2 if z86b==1
replace owner =3 if z86b==3
replace owner =5 if z86b==4
replace owner =6 if z86b==5

keep idnum year hrf_quer quer* bula bran_n09 br19fb ges_bes tarif owner tech_equip inno* vorlei* inv* empl_* x06* ///
	wage_total bluecoll_wanted bea* *business_vol* betrrat need* founded plant_sizeclass single
compress
save "$data\iabbp_2018.dta", replace


*-------------------------------------------------------------------------------
* Wave 2019 
*-------------------------------------------------------------------------------
use "$orig\iab19ges.dta", clear
keep if quer2019==1		// select cross-sectional data format
gen year=2019
cap ren babula 	bula2019
recode bula2019 (7=18) // fix regional classification
ren bula2019 	bula
ren hr2019q  	hrf_quer			
ren ba91b 		bran_n09
ren grkl2019	plant_sizeclass
ren ba30ges		ges_bes
ren ba01ges18	empl_L1
replace ba21=0 if ba20e==1 		// fix investments

ren ba08a 		x06a 
ren ba08b 		x06b
ren ba11 		business_vol	
ren ba12c 		business_vol_abroad
ren ba14	 	vorleis	
ren ba15b		need_staff
ren ba18proz 	dev_business_vol 		
ren ba20a 		inv_geba			
ren ba20b 		inv_edv			
ren ba20c 		inv_prod			
ren ba20d 		inv_verk			
ren ba20e 		inv_kein			
ren ba21 		invest	
ren ba22 		invest_add 
ren ba23 		tech_equip	
ren ba27	 	inno4	
ren ba26	 	inno3	
ren ba25	 	inno2	
ren ba24	 	inno1	
ren ba28ba		inno_highcost	
ren ba28bb		inno_highrisk	
ren ba28bc		inno_nocredit	
ren ba28be		inno_noqualstaff	
ren ba28bg		inno_laws	
ren ba30einf 	bea_einf		
ren ba37 		bluecoll_wanted	
ren ba63		tarif	
ren ba66 		wage_total	
ren ba81 		betrrat	
ren ba88		single	
ren ba89b 	founded
replace founded=999 if ba89a==1
ren br19fb19	br19fb

gen owner=.		
replace owner =4 if ba86a==1
replace owner =6 if ba86a==3
replace owner =1 if ba86b==2
replace owner =2 if ba86b==1
replace owner =3 if ba86b==3
replace owner =5 if ba86b==4
replace owner =6 if ba86b==5

* robot dummy
ren ba77a 		D_robot
* number of robots per year
ren ba77b14 	robots_2014
ren ba77b15 	robots_2015
ren ba77b16 	robots_2016
ren ba77b17 	robots_2017
ren ba77b18 	robots_2018
* number of robots with price less than 50.000€ (cheap_robot==1)
ren ba78 	cheap_robots
* number of robots in cage etc.
ren ba79 	cage_robots
* number of new robots in 2018
ren ba80		new2018_robots

*** cleaning robot data
* robot dummy:
replace D_robot=. if D_robot==-9
replace D_robot=0 if D_robot==2
tab D_robot

* recode missing values:
foreach x in robots_201* cage_robots cheap_robots new2018_robots { 
	mvdecode `x', mv(-9)
}


tab ba28a
tab ba28a, nolabel
* replace missings in ba28b with 0 if ba28a is missing
tab  inno_highcost, nolabel
tab  inno_highrisk, nolabel
replace  inno_highcost=0 if  inno_highcost==-9 & ba28a==2
replace  inno_highrisk=0 if  inno_highrisk==-9 & ba28a==2
replace  inno_nocredit=0 if  inno_nocredit==-9 & ba28a==2
replace  inno_noqualstaff=0 if  inno_noqualstaff==-9 & ba28a==2
replace  inno_laws=0 if  inno_laws==-9 & ba28a==2

keep idnum year hrf_quer quer* bula bran_n09 br19fb ges_bes tarif owner tech_equip inno* vorlei* inv* empl_* x06*  ///
	wage_total bluecoll_wanted bea* *business_vol* betrrat need* founded plant_sizeclass single ///
	robots_201* D_robot cheap_robots cage_robots new2018_robots
compress
save "$data\iabbp_2019.dta", replace


cap log close


