cap log close
local date: di %d date(c(current_date),"DMY")
log using $log\IAB_panel_`date'.log , replace
*-------------------------------------------------------------------------------
* PANEL GENERATION OUT OF IAB WAVES (2013-2019).
*-------------------------------------------------------------------------------
use "$data\iabbp_2019.dta", clear

* appending previous waves
local y=2018
while `y'>2012  {
append using "$data\iabbp_`y'.dta"
local y=`y'-1
}

* sorting variables
compress
sort idnum year

#delimit ;
capture order
	idnum year robots_201* D_robot cheap_robots cage_robots new2018_robots robot_cnc_y77ga robot_cnc_y77gb /// 
	digitization_x25a digitization_x25b digitization_x25c owner tech_equip inno* vorlei* inv* empl_* ///
	wage_total bluecoll_wanted bea* *business_vol* betrrat x06* x05* need* founded
	;
#delimit cr
compress

* sector classification and manufacturing dummy
rename bran_n09 IAB_43
gen manuf=1 if IAB_43>3 & IAB_43<18
replace manuf=0 if (IAB_43<=3 | IAB_43>=18) & IAB_43!=.
tab manuf,m 

*calculate weighted employee number per sector year:
bys idnum year: gen empl_L1_weighted=hrf_quer*empl_L1
bys IAB_43 year: egen empl_L1_weighted_sector=total(empl_L1_weighted)


* decode missing values
foreach x in owner tech_equip inno* vorlei* inv* empl_* wage_total bluecoll_wanted bea* *business_vol* betrrat x06* x05* need* founded minwage_w66a { 
	mvdecode `x', mv(-9)
}

* recoding
sum inv* inno* x06* x05*
local recode "inno1 inno2 inno3 inno4 x06b bluecoll_wanted"
foreach x in `recode' {
	replace `x'=0 if `x'==2		
	}

* generate dummy for foreign ownership:
tab owner, m
tab owner, m nolabel
bys idnum year: gen D_foreign_owner=1 if owner==3
replace D_foreign_owner=0 if owner==1 | owner==2
label var D_foreign_owner "Dummy for foreign ownership (=1 if true)"

* generate dummy for collective wage agreement:
tab tarif, m 
tab tarif, m nolabel
bys idnum year: gen D_tarif=1 if tarif==1 | tarif==2
bys idnum year: replace D_tarif=0 if tarif==3
tab D_tarif 
label var D_tarif "Dummy for collective wage agreement (=1 if true)"

* dummy for works council
cap label drop betrrat
tab betrrat, m 
tab betrrat, m nolabel
recode betrrat (2 = 0), gen(D_betrrat)
label var D_betrrat "Dummy for works council/staff council (=1 if true)"

* check missing values of robot stock by industry: NONE
tabstat idnum if D_robot==1 &  robots_2018==.  , by(br19fb) stats(count) labelwidth(32)

* Label variables and values
cap label drop plant_sizeclass
label define plant_sizeclass 1 "1-4 employees" 2 "5-9 employees" 3 "10-19 employees" 4 "20-49 employees" 5 "50-99 employees" 6 "100-199 employees" 7 "200-499 employees" 8 "500-999 employees" 9 "100-4999 employees" 10 "5000+ employees"
label value plant_sizeclass plant_sizeclass

tab need_staff
label var need_staff "additional staff needed to increase sales"

cap label drop x05*
label var x05a "Staffing problems: too many employees"
label var x05b "Staffing problems: high labor turnover"
label var x05c "Staffing problems: skilled workers hard to find"
label var x05d "Staffing problems: staff shortage"
label var x05e "Staffing problems: ageing population"
label var x05f "Staffing problems: demand for further training"
label var x05g "Staffing problems: lacking motivation"
label var x05h "Staffing problems: many absences/sickness leaves"
label var x05i "Staffing problems: high labor costs"
label var x05j "Staffing problems: others"
label var x05k "Staffing problems: none"

cap label drop x06*
label var x06a "Degree of competitive pressure"
label var x06b "Estab. endangered by competitive pressure"

cap label drop inno*
label var inno1 "Product improved or refined"
label var inno2 "Existing product newly included in offering"
label var inno3 "Completely new product included in offering"
label var inno4 "Improved procedures developed or implemented"

*investments
label var invest "Sum of all investments in prev. year in €"
label var inv_geba "Invest. in real estate and buildings"
label var inv_edv "Invest. in communication technology/data processing"
label var inv_prod "Invest. in other production facilities"
label var inv_verk "Invest. in means of transport/transportation systems"
label var inv_kein "No investments"
label var invest_add "Proportion expansion invest. on total invest. (in %)"

* relabel values of dummy variables:
local x "x05a x05b x05c x05d x05e x05f x05g x05h x05i x05j x05k x06b inno1 inno2 inno3 inno4 inv_edv inv_geba inv_kein inv_prod inv_verk need_staff D_betrrat D_tarif bluecoll_wanted"
foreach x in `x' {
label define `x'_label 0 "No" 1 "Yes"
label value `x' `x'_label
sum `x'
}

* label regional information
label define bula 0 "Berlin/West" 1 "Schleswig-Holstein" 2 "Hamburg" 3 "Niedersachsen" 4 "Bremen" 5 "Nordrhein-Westfalen" ///
			6 "Hessen" 7 "Rheinland-Pfalz/Saarland" 8 "Baden-Wuerttemberg" 9 "Bayern" 10 "Saarland" 11 "Berlin" 12 "Brandenburg" ///
			13 "Mecklenburg-Vorpommern" 14 "Sachsen" 15 "Sachsen-Anhalt" 16 "Thuehringen" 18 "Rheinland-Pfalz"
label value bula bula 

label define IAB_43	1 "agriculture/forestry" 2 "mining" 3 "energy" 4 "food/luxury" 5 "textiles/clothing"6 "paper/print/wood" ///
	7 "chemical/pharmaceutical sector" 8 "plastics industry" 9 	"glass/ceramic" 10 "basic metals" ///
	11 "fabricated metal" 12 "electrical equipment" 13 "precision/optical equipment "14 "machinery and equipment" ///
	15 "motor vehicles" 16 "furniture/jewelry/sports/medical supplies" 17 "repair/installation" 18 "main building sector" ///
	19 "building/installation"  20  "sales, maintenance, repair of motor vehicles" 21  "wholesale trade" 22  "retail trade" ///
	23  "transport/warehousing" 24  "information/communication publishing" 25  "hotel business/gastronomy" 26  "financial/insurance sector" ///
	27  "real estate activities" 28  "legal accounting/advertising" 29  "consulting" 30  "architecture, technical/physical/chemical support" ///
	31  "research/development" 32  "marketing/design/translation" 33  "veterinary industry" 34  "renting" 35  "placement/temporary provision of labor" ///
	36  "itinerant trading/landscaping" 37  "education" 38  "human health" 39  "culture/sports/entertaining" 40  "reparation of cosumer goods" ///
	41  "other services" 42  "activities of membership" 43  "civil service/social insurance" ///
	0 "residual non-manufacturing" 200 "all manufacturing" 100 "all non-manufacturing"
label value IAB_43 IAB_43


save "$data\panel_v1.dta", replace

cap log close
