capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\impute_reshape_`date'.log, replace
*-------------------------------------------------------------------------------
* IMPUTATION AND RESHAPING OF ROBOT DATA IN IAB WAVE 2019.
*-------------------------------------------------------------------------------
cd "$main"
set more off
clear all

*-------------------------------------------------------------------------------
* IMPUTATION BASED ON 2017 WAVE
*-------------------------------------------------------------------------------
use "$data\panel_v1.dta", clear
xtset idnum year
cap drop D_robot *robots* _merge  
sum *robot*		// only 2017 robot questions remain
merge 1:1 idnum year using "$data\robot_v1.dta"		// merge with cleaned robot data robot_v1
tab robot_cnc_y77ga if year==2017, m nolabel

* transfer 2017 question to 2019 wave (technical step for imputation):
replace robot_cnc_y77ga=L2.robot_cnc_y77ga if year==2019

* imputation rule: replace robot=0 for 2017 and backwards if robot is missing and no CNC/robot use in 2017
gen flag_i1=0
replace flag_i1 = 1 if robot_cnc_y77ga==0 & D_robot==1 & robots_2017>=.
label variable flag_i1 "imputed value = 0 if missing robot use in 2017 and answered no to CNC/robot question in 2017 wave" 
replace robots_2017=0 if robot_cnc_y77ga==0 & D_robot==1 & robots_2017>=.
gen help = 1 if flag_i1==1 & robots_2016>=. & robots_2015>=. & robots_2014>=.
replace robots_2016=0 if help==1 & founded<=2016 //*Assumption: y77ga refers to earlier years as well JS
replace robots_2015=0 if help==1  & founded<=2015
replace robots_2014=0 if help==1 & founded<=2014
drop help

*-------------------------------------------------------------------------------
* IMPUTATION OF ROBOT VARIABLES BASED ON 2018 STOCKAND NEW DELIVERIES
*-------------------------------------------------------------------------------
gen flag_i3=0
replace flag_i3 = 1 if D_robot==1 & new2018_robots>=robots_2018 & new2018_robots<. & (robots_2017>=. | flag_i1==1)
label variable flag_i3 "imputed value=0 if missing robot use in 2017 and new delivery in 2018 >= stock in 2018" 

replace robots_2017 = 0 if D_robot==1 & new2018_robots>=robots_2018 & new2018_robots<. & robots_2017>=. 
gen help = 1 if flag_i3==1 & robots_2016>=. & robots_2015>=. & robots_2014>=.
replace robots_2016=0 if help==1
replace robots_2015=0 if help==1
replace robots_2014=0 if help==1
drop help

xtset idnum year
tsfill, full

*-------------------------------------------------------------------------------
* RESHAPING CLEANED AND IMPUTED ROBOT STOCK VARIABLE (2013-2019) 
*-------------------------------------------------------------------------------
preserve
* reshape robot variable and create "year" variable that refers only to robot use. 
	keep if year==2019
	keep idnum robots_201* D_robot robot_cnc_y77ga *quer* new2018_robots manuf  *robot* cage_robots cheap_robots
	* reshape robots_* variable in 2019 wave and keep only robot data:
	reshape long robots_, i(idnum) j(year)
	sort idnum year 
	rename robots_ robots
save "$data\robot_v2_help.dta", replace
restore
*** MERGING RESHAPED ROBOT STOCK VARIABLE AGAIN WITH THE PANEL DATASET:
	drop _merge *robots* 
	xtset idnum year
	merge m:1 idnum year using "$data\robot_v2_help.dta"

*-------------------------------------------------------------------------------
* ADJUSTING PANEL DATASET (LAGGING/EXPANDING CERTAIN VARIABLES) 
*-------------------------------------------------------------------------------
xtset idnum year
* copy foundation year information from 2019 to all other years:
	replace founded=F6.founded if founded==. & year==2013
	forvalue i=14/19 {
	replace founded=L.founded if founded==. & year==20`i' 
	}
	
foreach x in D_robot bula  IAB_43 manuf {
	qui replace `x'=F6.`x' if `x'==. & year==2013 
	forvalue i=14/19 {
	qui replace `x'=L.`x' if `x'==. & year==20`i' 
	}
	replace `x'=. if founded>year & founded!=.
}

replace manuf=1 if IAB_43>3 & IAB_43<18
replace manuf=0 if (IAB_43<=3 | IAB_43>=18) & IAB_43!=.

* apply quer2019 to year 2018 for technical reasons (will be reversed below): 
	bys idnum: replace quer2019=quer2019[_n+1] if year==2018
* calculate weighted number of employees per plant in 2019 wave:
	bys idnum: gen empl_weighted= empl_L1*hrf_quer if year==2019 
	label var empl_weighted "representative number of employees per plant in 2018 (empl_L1 from 2019 wave)"

* transfer the weighted employee number of 2019 wave to 2018 in order to calculate robot density based on correct sample later on:
	bys idnum : replace empl_weighted=F1.empl_weighted if year==2018
	replace empl_weighted=. if year==2019

* some variables have to be lagged by one period due to survey question: 
	xtset idnum year 
	local lagged "business_vol business_vol_abroad vorleis inno1 inno4  invest invest_add inno_noqualstaff"
	foreach x in `lagged' {
	bys idnum: replace `x'=F1.`x' if year==2013 
	bys idnum: replace `x'= F1.`x' if year==2014
	bys idnum: replace `x'= F1.`x' if year==2015
	bys idnum: replace `x'= F1.`x' if year==2016
	bys idnum: replace `x'= F1.`x' if year==2017
	bys idnum: replace `x'= F1.`x' if year==2018
	bys idnum: replace `x'= F1.`x' if year==2019
	replace `x'=. if year==2019 
	}

* fill in gaps for missings employment variables using ges_bes and empl_L1 from previous or subsequent year:
	sum idnum if year==2018 & robots!=. & quer2018!="Q"
	xtset idnum year
	bys idnum: replace ges_bes=F1.empl_L1 if ges_bes==.
	bys idnum: replace empl_L1=L1.ges_bes if empl_L1==.

* to weight robot numbers a separate variable is created that stored the 2019 crossectional weight:
	xtset idnum year
	bys idnum: gen hrf_robot= F1.hrf_quer if year==2018
	label var hrf_robot "t-1 cross-sectional weight from 2019 wave to be used for robots_2018"

* for analysis of robot stock in 2018 the industry classification for 2019 (br19fb) has to be copied to 2018 in panel:
	bys idnum: replace br19fb= F1.br19fb if year==2018

* previously quer2019 information was copied into year 2018 for technical reasons. now reverse:
	bys idnum: replace quer2019=. if year==2018
	tostring quer2019,replace force
	replace quer2019="Q" if quer2019=="1"
	
save "$data/panel_v2.dta", replace
capture log close
