capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\indicators_`date'.log, replace
*-------------------------------------------------------------------------------
* CONSTRUCTION OF INDICATORS
*-------------------------------------------------------------------------------
cd "$main"
set more off
clear all

*-------------------------------------------------------------------------------				
{ // ROBOT DATA	
*-------------------------------------------------------------------------------				
use "$data/panel_v2.dta", clear 
xtset idnum year
* logarithm for employees and robots 
	bysort idnum year: gen log_ges_bes= log(ges_bes)
	bysort idnum year: gen log_robots= log(robots)

* we already defined a robot user dummy based on extensive margin survey question (D_robot==1 if plant uses robots in 2014-2018):
tab D_robot year

* generate YEARLY dummy for robot use based on intensive margin survey question for regression settings later on (D_robot_yearly==1 ) 	
	bys idnum year: gen D_robot_yearly=1 if D_robot==1 & robots>=1 & robots<. & (founded<=year | founded==.)
	bys idnum year:	replace D_robot_yearly=0 if robots==0 & robots<. & (founded<=year | founded==.)
	replace D_robot_yearly=0 if D_robot==0 & (founded<=year | founded==.)
*ASSUMPTION: as only 2 plants decrease their robot stock to 0 over time (7 other plants decrease stock, but not to 0), we assume the following: 
*				For plants that answered the extensive margin with "yes", but did not report the robot stock in 2018, we assume that they 
*				follow the same pattern as >99% of our sample, such that they used robots in 2018. 
di 2/556
di 7/556
replace D_robot_yearly=1 if D_robot==1 & robots==. & year==2018 & (founded<=year | founded==.)
tab D_robot_yearly if year==2018 & D_robot==1,m

label var D_robot_yearly "yearly dummy for robot use (true if D_robot_yearly==1)"
tab D_robot_yearly year 

*** ROBOT ADOPTION (time invariant)***
// definition robot adopter: plant is robot user, has zero robots for at least one year and a positive number of robots for at least one year (we do not have a case where robot users reduces number of robots to zero)
// definition non-robot adopter: plant is non-robot user or has positive number of robot for whole panel.
	gen D_robot_adoption=.
	* NOTICE: replace D_robot_adoption==1 if plant has zero robots in one year and positive number of robots in following years 		
		bys idnum: egen help1=min(robots) if D_robot!=.						
		bys idnum: egen help2=max(robots) if D_robot!=.							
		bys idnum: replace D_robot_adoption=1 if D_robot==1 &  help1!=help2 & help1==0 &help2<.	// robots==0 but positive maximum number of robots 
	* NOTICE: for plants that report zero robots for all years, replace missing with 0
		bys idnum: replace D_robot_adoption=0 if D_robot_adoption==. & D_robot!=.  
		drop help*	
		tab D_robot_adoption year
		
	* NOTICE: 3 robot using plant decreased number of robots to zero over time. They cannot be counted as robot adopters: 
		unique idnum if (robots<L.robots | robots<L2.robots| robots<L3.robots | robots<L4.robots ) &  robots==0 & year==2018 
	* NOTICE: 2 plants decrease robots to zero over time:
		qui levelsof idnum  if (robots<L.robots | robots<L2.robots| robots<L3.robots | robots<L4.robots ) &  robots==0 & year==2018  , local(list)
		foreach x in `list' {
		qui replace D_robot_adoption=0 if idnum==`x'
		}

*** ROBOT ADOPTION EVENT (time variant, based on intensive margin)***
// definition robot adoption event: this dummy==1 for year in which a plant switches from 0 to positive number of robots (if in t-1 D_robot_yearly==0 and in t D_robot_yearly==1). Zero for all other cases:
	bys idnum: gen D_robot_adoption_event=1 if L.D_robot_yearly==0 & D_robot_yearly==1
	bys idnum: replace D_robot_adoption_event=0 if (L.D_robot_yearly==0 & D_robot_yearly!=1) & D_robot_yearly!=.
	bys idnum: replace D_robot_adoption_event=0 if D_robot_adoption_event==. & D_robot!=.
	label var D_robot_adoption_event "Dummy for event of robot adoption (==1 in year of adoption with switch from 0 to positive number of robots)"
tab D_robot_adoption_event year if D_robot_adoption==1

*** ROBOT ADOPTION ("2 YEAR WINDOWS"): to include time effect of adoption in cross-section regression later on 
xtset idnum year
* window=1 if robot was adopted in first period. window=2 if adopted in second. 
	bys idnum: gen D_windows=1 if (F.D_robot_adoption_event==1 | F2.D_robot_adoption_event==1) & year==2014
	bys idnum: replace D_windows=1 if (L.D_robot_adoption_event==1 | D_robot_adoption_event==1) & year==2016
	bys idnum: replace D_windows=2 if (F3.D_robot_adoption_event==1| F4.D_robot_adoption_event==1) & year==2014
	bys idnum: replace D_windows=2 if (F.D_robot_adoption_event==1 | F2.D_robot_adoption_event==1) & year==2016
* for non-adopters assign window=1 if year <=2016 (explanatories from 2014 will be used), window=2 if year== 2017 | year==2018 (expl from 2016 will be used)
	bys idnum: replace D_windows=1 if D_robot_adoption==0 & (F.D_robot_adoption_event==0 | F2.D_robot_adoption_event==0) & year==2014
	bys idnum: replace D_windows=2  if  D_robot_adoption==0 & (F.D_robot_adoption_event==0| F2.D_robot_adoption_event==0) & year==2016
tab D_windows year
tab D_windows D_robot_adoption

*** ROBOT DENSITY AT PLANT LEVEL (unweighted) *** 
	sort idnum year 
		bys idnum: gen robotdensity_pl=robots/(0.001*ges_bes)
		label var robotdensity_pl "robot density at plant level"  
		format robotdensity_pl %9.2f

*** AGGREGATED ROBOT DENSITY IN MANUFACTURING AND NON-MANUFACTURING (worker level)***
	bys manuf year: egen help1= total(robots*hrf_robot)	 if year==2018	
	bys manuf year: egen help2= total(ges_bes*hrf_robot)	 if year==2018	
	bys manuf year : gen robotdensity_manuf= (help1*1000)/(help2) if year==2018	
	label var robotdensity_manuf "aggregated robot density in manufacturing and non-manufacturing in 2018 (weighted)"
	drop help*
	format robotdensity_manuf %9.2f


*** AGGREGATED ROBOT DENSITY PER SECTOR (worker level)***
	bys IAB_43 year: egen help1= total(robots*hrf_robot)	 if year==2018	
	bys IAB_43 year: egen help2= total(ges_bes*hrf_robot)	 if year==2018	
	bys IAB_43 year: gen robotdensity_wlw= (help1*1000)/(help2) if year==2018	
	label var robotdensity_wlw "aggregated worker level robot density per sector in 2018 (weighted)"
	drop help*
	format robotdensity_wlw %9.2f

*** AGGREGATED ROBOT DENSITY PER REGION (worker level)***
	bys bula year: egen help1= total(robots*hrf_robot)	 if year==2018	
	bys bula year: egen help2= total(ges_bes*hrf_robot)	 if year==2018	
	bys bula year: gen robotdensity_region_w= (help1*1000)/(help2) if year==2018	
	label var robotdensity_region_w "aggregated worker level robot density per region in 2018 (weighted)"
	drop help*
}	

	
*-------------------------------------------------------------------------------				
{ // EXPLANATORY VARIABLES			
*-------------------------------------------------------------------------------	
***	SKILL INTENSITY 
	sort idnum year
	* skill shares by plant:
		foreach x in bea_uni bea_ber bea_einf {
		bys idnum year: gen `x'_share = `x'/ges_bes	if `x'!=. & ges_bes!=.	/* create variable for share of high skill workers by plant  */
		}
		
		ren bea_uni_share highskill
		ren bea_ber_share mediumskill 
		ren bea_einf_share lowskill 

		bys idnum year: replace highskill=1 if highskill>1	& highskill<.	// some skill values were imputed as mean of two years, adjust here the max
		bys idnum year: replace mediumskill=1 if mediumskill>1	& mediumskill<.
		bys idnum year: replace lowskill=1 if lowskill>1 & lowskill<.
		
		bys idnum year: gen skill_resid_share = 1-highskill - mediumskill - lowskill
		sum skill_resid_share,d
		
	xtset idnum year 
	* NOTICE: employee demographics and skills are only bi-yearly variables. Impute the years inbetween as mean: 
		foreach x in highskill mediumskill lowskill {
		bys idnum: replace `x'=(F1.`x'+L1.`x')/2 if `x'==. & F1.`x'!=.  & L1.`x'!=. 
		}
		label var highskill "share of employees with university degree"
		label var mediumskill "share of employees with apprenticeship"		 				
		label var lowskill "share of employees without university degree or apprenticeship"	
	
***	CATEGORIES FOR FIRM SIZE in 2018 ***		// aggregate the 10 firm-size classes in IAB survey into 5 categories 
	gen plantsize=.
	replace plantsize =1 if (plant_sizeclass==1 | plant_sizeclass==2)
	replace plantsize =2 if (plant_sizeclass==3 | plant_sizeclass==4)
	replace plantsize =3 if (plant_sizeclass==5 | plant_sizeclass==6)
	replace plantsize =4 if (plant_sizeclass==7 | plant_sizeclass==8 | plant_sizeclass==9 | plant_sizeclass==10)
	label define plant_size 1 "<10 employees" 2 "10-49 employees" 3 "50-199 employees" 4 "> 200 employees" 
	label values plantsize plant_size
	tab plant*

*** TECHNICAL EQUIPMENT
	label define tech_equip 1 "up to date" 2 "relatively up to date" 3 "average" 4 "relatively outdated" 5 "completely outdated"
	label value tech_equip tech_equip
	label var tech_equip "status of technical equipment"
	* generate a tech dummy with only 2 categories:
	bys idnum year: gen D_tech=1 if tech_equip!=. & (tech_equip==1 | tech_equip==2)
	bys idnum year: replace D_tech=0 if tech_equip!=. & (tech_equip==3 | tech_equip==4 | tech_equip==5 )
	label define D_tech 1 "(relatively) up to date/" 0 "(relatively) outdated/ completely outdated"
	label value D_tech D_tech
	label var D_tech "dummy for status of technical equipment (==1 if up to date) "
	
*** PLANT LEVEL WAGE
	bys idnum year: gen wage= wage_total/ges_bes 
	label var wage "monthly labor costs per employee"
	sum wage wage_total
	bys idnum year: gen log_wage=log(wage)
	label var log_wage "monthly log gross wage per employee "

* DUMMY FOR COMPETITIVE PRESSURE
	tab x06a
	tab x06b if year==2014,m
	bys idnum year: gen D_competition=0 if x06a==1 | x06a==2 | x06a==3
	bys idnum year: replace D_competition=1 if x06a==4
	bys idnum year: replace D_competition=1 if x06b==1
	bys idnum year: replace D_competition=0 if x06b==0
	label var D_competition "Competitive pressure (==1 if very high)"

* EXPORT (extensive margin):
	sum business_vol_abroad
	bys idnum year: gen D_export=1 if business_vol_abroad!=. & business_vol_abroad!=0
	bys idnum year: replace D_export=0 if business_vol_abroad==0 
	label var D_export "time varying dummy for export (=1 if true)"

* EXPORT (intensive margin)
	sum business_vol_abroad
	bys idnum year: gen busi_vol_abroad=business_vol_abroad*business_vol/100
	bys idnum year: gen log_exportvol=log(busi_vol_abroad)
	label var log_exportvol "log of total businee volume abroad (intensive margin of export)"

* MINIMUM WAGE (from wave 2015)
	xtset idnum year 
	codebook minwage_w66a
	tab minwage_w66a, nol
	replace minwage_w66a=. if minwage_w66a==3		// recode answer "unknown" as missing
	replace minwage_w66a=0 if minwage_w66a==2
	ren minwage_w66a D_minwage_w66a
	
	label var D_minwage_w66a "wages raised due to minimum wage in 2015 (=1 if true), survey question w66a"
	label define D_minwage_w66a 0 "No" 1 "Yes"
	label values D_minwage_w66a D_minwage_w66a
	
* write min wage information to all years:
	foreach x in D_minwage_w66a  {
	cap drop help
	bys idnum: egen help = min(`x')
	bys idnum: replace `x'=help if `x'==.
	}

* generate dummies for labor scarcity:
codebook x05*,c
replace x05f=0 if x05k==1 // if no staff problems, then also no specific staff problems 
replace x05c=0 if x05k==1 // if no staff problems, then also no specific staff problems 

	bys idnum year: gen D_lscarcity=1 if  x05c==1 | x05d==1  | need_staff==1 | inno_noqualstaff==1 
	bys idnum year: replace D_lscarcity=0 if (x05c==0 & x05d==0) |  need_staff==0 | inno_noqualstaff==0 |x05k==1
	label var D_lscarcity "Dummy for all types of labor scarcity (==1 if true)"

	bys idnum year: gen D_lscarcity_hs=1 if  x05c==1 | x05f==1  |  inno_noqualstaff==1 
	bys idnum year: replace D_lscarcity_hs=0 if (x05c==0 & x05f==0) |  D_lscarcity==0 |  need_staff==0 | inno_noqualstaff==0 |x05k==1
	label var D_lscarcity_hs "Dummy for labor scarcity for high skilled workers (==1 if true)"

	ren inno_noqualstaff inno_noqual

* generate overall dummy for problems with staff:
	bys idnum year: gen D_staff=1 if x05a==1 | x05b==1 |  x05c==1 | x05d==1  | x05e==1 | x05f==1 | x05g==1 | x05h==1 | x05i==1 | x05j==1 | need_staff==1
	bys idnum year: replace D_staff=1 if x05k==0
	bys idnum year: replace D_staff=0 if x05k==1
	bys idnum year: replace D_staff=0 if x05a==0 & x05b==0 &  x05c==0 & x05d==0  & x05e==0 & x05f==0 & x05g==0 & x05h==0 & x05i==0 & x05j==0 & need_staff==0
	label var D_staff "Dummy for all types of staffing problems (==1 if true)"
}
	

save "$data/panel_v3.dta", replace

cap log close