capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\cap_stock_approx_`date'.log, replace
*-------------------------------------------------------------------------------
* CAPITAL STOCK APPROXIMATION BASED ON MUELLER (2017)
*-------------------------------------------------------------------------------
cd "$main"
set more off
clear all
*-------------------------------------------------------------------------------
* extrapolation of average life time of capital stock to years 2015-2018 based 
* on arithmetic mean from 1991-2014.
*-------------------------------------------------------------------------------
cd "$main"
set more off
clear all

use "$orig\nd_w08_2.dta", clear
xtset w08_2 year

* growth rate of nd
gen lnd = l.nd
gen gr_nd = (l.nd - nd) / l.nd

* generate years 2015, 2016, 2017 for each sector
sort year w08_2

set obs 2041
replace year = 2015 in 2041

set obs 2042
replace year = 2016 in 2042

set obs 2043
replace year = 2017 in 2043

set obs 2044
replace year = 2018 in 2044

set obs 2045
replace year = 2019 in 2045

set obs 2046
replace year = 2020 in 2046

replace w08_2 = 1 in 2041
replace w08_2 = 1 in 2042
replace w08_2 = 1 in 2043
replace w08_2 = 1 in 2044
replace w08_2 = 1 in 2045
replace w08_2 = 1 in 2046

* create wz year combinations
fillin year w08_2
sort w08_2 year

* mean of 1991 - 2014
egen amean2 = mean(gr_nd), by(w08_2)

* calculate values for 2015 -2019:
replace nd = nd[_n-1]*amean2 + nd[_n-1] if nd == . & w08_2 == w08_2[_n-1]

keep w08_2 year nd
compress
save "$data\nd_w08_2_extra.dta", replace

ren w08_2 wz08_2d
save "$data\nd_w08_2.dta", replace

*-------------------------------------------------------------------------------
* prepare the 3-digit WZ08 from BHP data:
import spss using "${orig}\WZ08_19_IWH.sav", clear 	
sum wz*
destring wz08_19, replace 
xtset idnum wz08_19
gen wz08_2d=int(wz08_19/1000) // adapt the 5 digit to 2-digit level 
format wz08_2d  %2.0f
gen wz08_3d=int(wz08_19/100) // adapt the 5 digit to 3-digit level 
format wz08_3d  %4.0f
sum *wz08*
keep idnum wz08_19 wz08_2d wz08_3d								
save "$data\wz08.dta", replace													

use "$data\panel_v3.dta", clear
drop if idnum == .
xtset idnum year
cap destring wz08_19, force replace
cap destring wz08_2d, force replace
cap destring wz08_3d, force replace

cap drop _merge
merge m:1 idnum using "$data\wz08.dta"											
drop _merge

* not for all plants the wz08 is known:
tabstat idnum if wz08_2d==. & year==2019 & D_robot!=., stats(N)  
tabstat idnum if wz08_2d==. & year==2019 & D_robot==1, stats(N)
* for some of these the IAB_43 can exactly identify the industry:
replace wz08_2d=22 if IAB_43==8  & wz08_2d==.
replace wz08_2d=23 if IAB_43==9  & wz08_2d==.
replace wz08_2d=24 if IAB_43==10  & wz08_2d==.
replace wz08_2d=25 if IAB_43==11 & wz08_2d==.
replace wz08_2d=26 if IAB_43==12  & wz08_2d==.
replace wz08_2d=27 if IAB_43==13  & wz08_2d==.
replace wz08_2d=28 if IAB_43==14  & wz08_2d==.

replace wz08_2d=33 if IAB_43==17  & wz08_2d==.
replace wz08_2d=43 if IAB_43==19  & wz08_2d==.
replace wz08_2d=45 if IAB_43==20  & wz08_2d==.
replace wz08_2d=46 if IAB_43==21  & wz08_2d==.
replace wz08_2d=47 if IAB_43==22  & wz08_2d==.

replace wz08_2d=68 if IAB_43==27  & wz08_2d==.
replace wz08_2d=69 if IAB_43==28  & wz08_2d==.
replace wz08_2d=70 if IAB_43==29  & wz08_2d==.
replace wz08_2d=71 if IAB_43==30  & wz08_2d==.
replace wz08_2d=72 if IAB_43==31  & wz08_2d==.

replace wz08_2d=75 if IAB_43==33  & wz08_2d==.
replace wz08_2d=77 if IAB_43==34  & wz08_2d==.
replace wz08_2d=78 if IAB_43==35  & wz08_2d==.

replace wz08_2d=85 if IAB_43==37  & wz08_2d==.

replace wz08_2d=95 if IAB_43==40  & wz08_2d==.
replace wz08_2d=96 if IAB_43==41  & wz08_2d==.
replace wz08_2d=94 if IAB_43==42  & wz08_2d==.
replace wz08_2d=84 if IAB_43==43  & wz08_2d==.

merge m:1  wz08_2d year using "data\nd_w08_2.dta"
drop _merge

ren invest inv
ren nd NDbp
ren invest_add inv_dK
ren inv_kein INo 
ren inv_geb IPlant
ren inv_edv IIT
ren inv_prod IProd
ren inv_verk ITransp
ren wz08_2d sectornew


********************************************************************************
*************************** Capital Stock approximation ************************
* Müller, Steffen (2017): Capital Stock approximation with the perpetual
* inventory method: An update. FDZ-Methodenreport, 05/2017. Nürnberg.

******* Capital Stock Approximation with the IAB Establishment Panel 
* When applying the method please refer to: * Mueller, Steffen (2008), "Capital Stock Approximation Using Firm Level  * Panel Data", Jahrbücher für Nationalökonomie und Statistik, 228(4) 
**************************************************************************** 
* Prerequisites: 
* IAB establishment data as a panel data set 
* All variables that refer to the previous year (e.g. investments) but are asked  
* in the current year have to be moved to the previous year. 
* Please make sure that the industry codes for all years of panel participation  
* are translated into the wz93 industry codes that are used from year 2000 on.  
**************************************************************************** 
* This program follows paper and Section 3 above and is organized as follows: 
* 1. import the average economic lives of industry capital stock (ND) from the national accounts 
* 2. generate economic lives for net investments with information from the German federal statistical office 
* 3. multiply the replacement investment for each firm-year observation with the ND 
* 4. create a starting value for perpetual inventory and perform perpetual inventory 
* 4.1 Version I for estimators that rely mainly on between-firm information (e.g. OLS) 
* 4.2 Version II for estimators that use only within-firm information (e.g. Fixed Effects, First Differences, GMM-Diff, GMM-SYS) 
**************************************************************************** **************************************************************************** 

* 1. import the average economic lives (in years) of industry capital stock (ND) from the national accounts 
 * variables from the IAB Establishment Panel: 
 * sectornew is the industry code of the wz93 classification, in the IAB Establishment Panel routinely coded from 2000 on 
 * year is the year of observation, 96 = 1996, 97 = 1997, ..., 107 = 2007 
gen ND = . 
 replace ND = 24.8 if sectornew==1 & year == 96 
 replace ND = 24.0 if sectornew==2 & year == 96 
 replace ND = 18.2 if sectornew==3 & year == 96 
 replace ND = 21.0 if sectornew==4 & year == 96 
 replace ND = 15.8 if sectornew==5 & year == 96 
 replace ND = 20.0 if sectornew==6 & year == 96 
 replace ND = 16.1 if sectornew==7 & year == 96 
 replace ND = 15.6 if sectornew==8 & year == 96 
 replace ND = 17.3 if sectornew==9 & year == 96 
 replace ND = 15.2 if sectornew==10 & year == 96 
 replace ND = 16.7 if sectornew==11 & year == 96 
 replace ND = 17.9 if sectornew==12 & year == 96 
 replace ND = 18.2 if sectornew==13 & year == 96 
 replace ND = 16.1 if sectornew==14 & year == 96 
 replace ND = 21.6 if sectornew==15 & year == 96 
 replace ND = 16.5 if sectornew==16 & year == 96
 replace ND = 17.0 if sectornew==17 & year == 96
 replace ND = 21.9 if sectornew==18 & year == 96
 replace ND = 16.9 if sectornew==19 & year == 96
 replace ND = 16.9 if sectornew==20 & year == 96
 replace ND = 21.4 if sectornew==21 & year == 96
 replace ND = 21.9 if sectornew==22 & year == 96
 replace ND = 21.5 if sectornew==23 & year == 96
 replace ND = 27.6 if sectornew==24 & year == 96
 replace ND = 23.3 if sectornew==25 & year == 96
 replace ND = 34.2 if sectornew==26 & year == 96
 replace ND = 44.4 if sectornew==27 & year == 96
 replace ND = 16.1 if sectornew==28 & year == 96
 replace ND = 32.6 if sectornew==29 & year == 96
 replace ND = 27.5 if sectornew==30 & year == 96
 replace ND = 65.7 if sectornew==31 & year == 96
 replace ND = 12.6 if sectornew==32 & year == 96
 replace ND = 26.4 if sectornew==33 & year == 96
 replace ND = 24.8 if sectornew==1 & year == 97
 replace ND = 24.1 if sectornew==2 & year == 97
 replace ND = 18.1 if sectornew==3 & year == 97
 replace ND = 21.2 if sectornew==4 & year == 97
 replace ND = 15.8 if sectornew==5 & year == 97
 replace ND = 20.0 if sectornew==6 & year == 97
 replace ND = 15.9 if sectornew==7 & year == 97
 replace ND = 15.6 if sectornew==8 & year == 97
 replace ND = 17.2 if sectornew==9 & year == 97
 replace ND = 15.1 if sectornew==10 & year == 97
 replace ND = 16.7 if sectornew==11 & year == 97
 replace ND = 17.8 if sectornew==12 & year == 97
 replace ND = 18.1 if sectornew==13 & year == 97
 replace ND = 16.1 if sectornew==14 & year == 97
 replace ND = 21.6 if sectornew==15 & year == 97
 replace ND = 16.4 if sectornew==16 & year == 97
 replace ND = 16.9 if sectornew==17 & year == 97
 replace ND = 21.8 if sectornew==18 & year == 97
 replace ND = 17.0 if sectornew==19 & year == 97
 replace ND = 17.0 if sectornew==20 & year == 97
 replace ND = 21.4 if sectornew==21 & year == 97
 replace ND = 22.1 if sectornew==22 & year == 97
 replace ND = 21.5 if sectornew==23 & year == 97
 replace ND = 27.5 if sectornew==24 & year == 97
 replace ND = 22.9 if sectornew==25 & year == 97
 replace ND = 34.4 if sectornew==26 & year == 97
 replace ND = 44.6 if sectornew==27 & year == 97
 replace ND = 16.2 if sectornew==28 & year == 97
 replace ND = 33.3 if sectornew==29 & year == 97
 replace ND = 27.4 if sectornew==30 & year == 97
 replace ND = 65.7 if sectornew==31 & year == 97
 replace ND = 12.6 if sectornew==32 & year == 97
 replace ND = 26.6 if sectornew==33 & year == 97
 replace ND = 24.9 if sectornew==1 & year == 98
 replace ND = 24.2 if sectornew==2 & year == 98
 replace ND = 17.9 if sectornew==3 & year == 98
 replace ND = 21.2 if sectornew==4 & year == 98
 replace ND = 15.7 if sectornew==5 & year == 98
 replace ND = 19.9 if sectornew==6 & year == 98
 replace ND = 15.8 if sectornew==7 & year == 98
 replace ND = 15.5 if sectornew==8 & year == 98
 replace ND = 17.1 if sectornew==9 & year == 98
 replace ND = 15.0 if sectornew==10 & year == 98
 replace ND = 16.7 if sectornew==11 & year == 98
 replace ND = 17.6 if sectornew==12 & year == 98
 replace ND = 18.0 if sectornew==13 & year == 98
 replace ND = 16.0 if sectornew==14 & year == 98
 replace ND = 21.4 if sectornew==15 & year == 98
 replace ND = 16.3 if sectornew==16 & year == 98
 replace ND = 16.8 if sectornew==17 & year == 98
 replace ND = 21.7 if sectornew==18 & year == 98
 replace ND = 17.0 if sectornew==19 & year == 98
 replace ND = 17.0 if sectornew==20 & year == 98
 replace ND = 21.4 if sectornew==21 & year == 98
 replace ND = 22.2 if sectornew==22 & year == 98
 replace ND = 21.5 if sectornew==23 & year == 98
 replace ND = 27.1 if sectornew==24 & year == 98
 replace ND = 22.8 if sectornew==25 & year == 98
 replace ND = 34.7 if sectornew==26 & year == 98
 replace ND = 44.9 if sectornew==27 & year == 98
 replace ND = 16.1 if sectornew==28 & year == 98
 replace ND = 33.7 if sectornew==29 & year == 98
 replace ND = 27.2 if sectornew==30 & year == 98
 replace ND = 65.6 if sectornew==31 & year == 98
 replace ND = 12.6 if sectornew==32 & year == 98
 replace ND = 26.7 if sectornew==33 & year == 98
 replace ND = 25.3 if sectornew==1 & year == 99
 replace ND = 24.4 if sectornew==2 & year == 99
 replace ND = 17.9 if sectornew==3 & year == 99
 replace ND = 21.4 if sectornew==4 & year == 99
 replace ND = 15.8 if sectornew==5 & year == 99
 replace ND = 20.0 if sectornew==6 & year == 99
 replace ND = 15.7 if sectornew==7 & year == 99
 replace ND = 15.5 if sectornew==8 & year == 99
 replace ND = 17.1 if sectornew==9 & year == 99
 replace ND = 15.0 if sectornew==10 & year == 99
 replace ND = 16.8 if sectornew==11 & year == 99
 replace ND = 17.5 if sectornew==12 & year == 99
 replace ND = 17.9 if sectornew==13 & year == 99
 replace ND = 16.0 if sectornew==14 & year == 99
 replace ND = 21.4 if sectornew==15 & year == 99
 replace ND = 16.3 if sectornew==16 & year == 99
 replace ND = 16.9 if sectornew==17 & year == 99
 replace ND = 21.7 if sectornew==18 & year == 99
 replace ND = 17.2 if sectornew==19 & year == 99
 replace ND = 17.2 if sectornew==20 & year == 99
 replace ND = 21.4 if sectornew==21 & year == 99
 replace ND = 22.3 if sectornew==22 & year == 99
 replace ND = 21.6 if sectornew==23 & year == 99
 replace ND = 27.0 if sectornew==24 & year == 99
 replace ND = 22.9 if sectornew==25 & year == 99
 replace ND = 35.1 if sectornew==26 & year == 99
 replace ND = 45.4 if sectornew==27 & year == 99
 replace ND = 16.0 if sectornew==28 & year == 99
 replace ND = 34.3 if sectornew==29 & year == 99
 replace ND = 27.0 if sectornew==30 & year == 99
 replace ND = 65.6 if sectornew==31 & year == 99
 replace ND = 12.6 if sectornew==32 & year == 99
 replace ND = 27.0 if sectornew==33 & year == 99
 replace ND = 26.3 if sectornew==1 & year == 100
 replace ND = 24.4 if sectornew==2 & year == 100
 replace ND = 17.9 if sectornew==3 & year == 100
 replace ND = 22.4 if sectornew==4 & year == 100
 replace ND = 15.9 if sectornew==5 & year == 100
 replace ND = 20.4 if sectornew==6 & year == 100
 replace ND = 15.8 if sectornew==7 & year == 100
 replace ND = 15.7 if sectornew==8 & year == 100
 replace ND = 16.9 if sectornew==9 & year == 100
 replace ND = 15.2 if sectornew==10 & year == 100
 replace ND = 18.8 if sectornew==11 & year == 100
 replace ND = 17.4 if sectornew==12 & year == 100
 replace ND = 17.5 if sectornew==13 & year == 100
 replace ND = 15.6 if sectornew==14 & year == 100
 replace ND = 21.0 if sectornew==15 & year == 100
 replace ND = 16.1 if sectornew==16 & year == 100
 replace ND = 18.0 if sectornew==17 & year == 100
 replace ND = 21.4 if sectornew==18 & year == 100
 replace ND = 18.5 if sectornew==19 & year == 100
 replace ND = 18.5 if sectornew==20 & year == 100
 replace ND = 23.6 if sectornew==21 & year == 100
 replace ND = 22.4 if sectornew==22 & year == 100
 replace ND = 20.7 if sectornew==23 & year == 100
 replace ND = 25.5 if sectornew==24 & year == 100
 replace ND = 24.5 if sectornew==25 & year == 100
 replace ND = 32.5 if sectornew==26 & year == 100
 replace ND = 46.9 if sectornew==27 & year == 100
 replace ND = 14.4 if sectornew==28 & year == 100
 replace ND = 26.1 if sectornew==29 & year == 100
 replace ND = 22.8 if sectornew==30 & year == 100
 replace ND = 65.3 if sectornew==31 & year == 100
 replace ND = 12.6 if sectornew==32 & year == 100
 replace ND = 26.9 if sectornew==33 & year == 100
 replace ND = 26.3 if sectornew==1 & year == 101
 replace ND = 24.6 if sectornew==2 & year == 101
 replace ND = 17.8 if sectornew==3 & year == 101
 replace ND = 22.5 if sectornew==4 & year == 101
 replace ND = 15.9 if sectornew==5 & year == 101
 replace ND = 20.3 if sectornew==6 & year == 101
 replace ND = 15.7 if sectornew==7 & year == 101
 replace ND = 15.7 if sectornew==8 & year == 101
 replace ND = 16.9 if sectornew==9 & year == 101
 replace ND = 15.1 if sectornew==10 & year == 101
 replace ND = 18.8 if sectornew==11 & year == 101
 replace ND = 17.2 if sectornew==12 & year == 101
 replace ND = 17.4 if sectornew==13 & year == 101
 replace ND = 15.5 if sectornew==14 & year == 101
 replace ND = 20.7 if sectornew==15 & year == 101
 replace ND = 16.0 if sectornew==16 & year == 101
 replace ND = 17.8 if sectornew==17 & year == 101
 replace ND = 21.4 if sectornew==18 & year == 101
 replace ND = 18.6 if sectornew==19 & year == 101
 replace ND = 18.6 if sectornew==20 & year == 101
 replace ND = 23.4 if sectornew==21 & year == 101
 replace ND = 22.3 if sectornew==22 & year == 101
 replace ND = 20.7 if sectornew==23 & year == 101
 replace ND = 25.1 if sectornew==24 & year == 101
 replace ND = 24.6 if sectornew==25 & year == 101
 replace ND = 32.7 if sectornew==26 & year == 101
 replace ND = 46.6 if sectornew==27 & year == 101
 replace ND = 14.1 if sectornew==28 & year == 101
 replace ND = 25.9 if sectornew==29 & year == 101
 replace ND = 21.2 if sectornew==30 & year == 101
 replace ND = 65.2 if sectornew==31 & year == 101
 replace ND = 12.6 if sectornew==32 & year == 101
 replace ND = 27.2 if sectornew==33 & year == 101
 replace ND = 26.3 if sectornew==1 & year == 102
 replace ND = 24.8 if sectornew==2 & year == 102
 replace ND = 17.7 if sectornew==3 & year == 102
 replace ND = 22.5 if sectornew==4 & year == 102
 replace ND = 15.8 if sectornew==5 & year == 102
 replace ND = 20.1 if sectornew==6 & year == 102
 replace ND = 15.6 if sectornew==7 & year == 102
 replace ND = 15.7 if sectornew==8 & year == 102
 replace ND = 16.8 if sectornew==9 & year == 102
 replace ND = 15.0 if sectornew==10 & year == 102
 replace ND = 18.9 if sectornew==11 & year == 102
 replace ND = 17.1 if sectornew==12 & year == 102
 replace ND = 17.3 if sectornew==13 & year == 102 
 replace ND = 15.3 if sectornew==14 & year == 102
 replace ND = 20.2 if sectornew==15 & year == 102
 replace ND = 15.9 if sectornew==16 & year == 102
 replace ND = 17.7 if sectornew==17 & year == 102
 replace ND = 21.3 if sectornew==18 & year == 102
 replace ND = 18.8 if sectornew==19 & year == 102
 replace ND = 18.8 if sectornew==20 & year == 102
 replace ND = 23.5 if sectornew==21 & year == 102
 replace ND = 22.3 if sectornew==22 & year == 102
 replace ND = 20.9 if sectornew==23 & year == 102
 replace ND = 25.0 if sectornew==24 & year == 102
 replace ND = 24.4 if sectornew==25 & year == 102
 replace ND = 33.1 if sectornew==26 & year == 102
 replace ND = 46.3 if sectornew==27 & year == 102
 replace ND = 13.8 if sectornew==28 & year == 102
 replace ND = 25.6 if sectornew==29 & year == 102
 replace ND = 20.0 if sectornew==30 & year == 102
 replace ND = 65.2 if sectornew==31 & year == 102
 replace ND = 12.6 if sectornew==32 & year == 102
 replace ND = 27.7 if sectornew==33 & year == 102
 replace ND = 26.4 if sectornew==1 & year == 103
 replace ND = 25.1 if sectornew==2 & year == 103
 replace ND = 17.7 if sectornew==3 & year == 103
 replace ND = 22.7 if sectornew==4 & year == 103
 replace ND = 15.8 if sectornew==5 & year == 103
 replace ND = 20.2 if sectornew==6 & year == 103
 replace ND = 15.6 if sectornew==7 & year == 103
 replace ND = 15.8 if sectornew==8 & year == 103
 replace ND = 16.9 if sectornew==9 & year == 103
 replace ND = 15.0 if sectornew==10 & year == 103
 replace ND = 18.8 if sectornew==11 & year == 103
 replace ND = 17.0 if sectornew==12 & year == 103
 replace ND = 17.4 if sectornew==13 & year == 103
 replace ND = 15.3 if sectornew==14 & year == 103
 replace ND = 20.1 if sectornew==15 & year == 103
 replace ND = 16.0 if sectornew==16 & year == 103
 replace ND = 17.8 if sectornew==17 & year == 103
 replace ND = 21.5 if sectornew==18 & year == 103
 replace ND = 20.3 if sectornew==19 & year == 103
 replace ND = 20.3 if sectornew==20 & year == 103
 replace ND = 23.7 if sectornew==21 & year == 103
 replace ND = 22.4 if sectornew==22 & year == 103
 replace ND = 21.1 if sectornew==23 & year == 103
 replace ND = 24.7 if sectornew==24 & year == 103
 replace ND = 24.4 if sectornew==25 & year == 103
 replace ND = 33.4 if sectornew==26 & year == 103
 replace ND = 46.1 if sectornew==27 & year == 103
 replace ND = 13.8 if sectornew==28 & year == 103
 replace ND = 26.1 if sectornew==29 & year == 103
 replace ND = 19.7 if sectornew==30 & year == 103
 replace ND = 65.2 if sectornew==31 & year == 103
 replace ND = 12.6 if sectornew==32 & year == 103
 replace ND = 28.3 if sectornew==33 & year == 103
 replace ND = 26.6 if sectornew==1 & year == 104
 replace ND = 25.7 if sectornew==2 & year == 104
 replace ND = 17.8 if sectornew==3 & year == 104
 replace ND = 23.0 if sectornew==4 & year == 104
 replace ND = 15.9 if sectornew==5 & year == 104
 replace ND = 20.5 if sectornew==6 & year == 104
 replace ND = 15.7 if sectornew==7 & year == 104
 replace ND = 15.9 if sectornew==8 & year == 104
 replace ND = 17.0 if sectornew==9 & year == 104
 replace ND = 15.1 if sectornew==10 & year == 104
 replace ND = 18.9 if sectornew==11 & year == 104
 replace ND = 17.1 if sectornew==12 & year == 104 
replace ND = 17.6 if sectornew==13 & year == 104
 replace ND = 15.3 if sectornew==14 & year == 104
 replace ND = 20.2 if sectornew==15 & year == 104
 replace ND = 16.1 if sectornew==16 & year == 104
 replace ND = 17.9 if sectornew==17 & year == 104
 replace ND = 21.7 if sectornew==18 & year == 104
 replace ND = 20.3 if sectornew==19 & year == 104
 replace ND = 20.3 if sectornew==20 & year == 104
 replace ND = 24.0 if sectornew==21 & year == 104
 replace ND = 22.6 if sectornew==22 & year == 104
 replace ND = 21.5 if sectornew==23 & year == 104
 replace ND = 24.8 if sectornew==24 & year == 104
 replace ND = 24.7 if sectornew==25 & year == 104
 replace ND = 33.8 if sectornew==26 & year == 104
 replace ND = 46.3 if sectornew==27 & year == 104
 replace ND = 13.8 if sectornew==28 & year == 104
 replace ND = 26.2 if sectornew==29 & year == 104
 replace ND = 19.9 if sectornew==30 & year == 104
 replace ND = 65.2 if sectornew==31 & year == 104
 replace ND = 12.7 if sectornew==32 & year == 104
 replace ND = 29.2 if sectornew==33 & year == 104
 replace ND = 26.7 if sectornew==1 & year == 105
 replace ND = 26.1 if sectornew==2 & year == 105
 replace ND = 17.8 if sectornew==3 & year == 105
 replace ND = 23.1 if sectornew==4 & year == 105
 replace ND = 15.8 if sectornew==5 & year == 105
 replace ND = 20.4 if sectornew==6 & year == 105
 replace ND = 15.8 if sectornew==7 & year == 105
 replace ND = 15.9 if sectornew==8 & year == 105
 replace ND = 17.1 if sectornew==9 & year == 105
 replace ND = 15.0 if sectornew==10 & year == 105
 replace ND = 18.6 if sectornew==11 & year == 105
 replace ND = 17.0 if sectornew==12 & year == 105
 replace ND = 17.6 if sectornew==13 & year == 105
 replace ND = 15.2 if sectornew==14 & year == 105
 replace ND = 20.0 if sectornew==15 & year == 105
 replace ND = 16.1 if sectornew==16 & year == 105
 replace ND = 17.9 if sectornew==17 & year == 105
 replace ND = 21.8 if sectornew==18 & year == 105
 replace ND = 20.3 if sectornew==19 & year == 105
 replace ND = 20.3 if sectornew==20 & year == 105
 replace ND = 24.3 if sectornew==21 & year == 105
 replace ND = 22.7 if sectornew==22 & year == 105
 replace ND = 21.9 if sectornew==23 & year == 105
 replace ND = 24.6 if sectornew==24 & year == 105
 replace ND = 24.6 if sectornew==25 & year == 105
 replace ND = 34.1 if sectornew==26 & year == 105
 replace ND = 46.2 if sectornew==27 & year == 105
 replace ND = 13.7 if sectornew==28 & year == 105
 replace ND = 25.9 if sectornew==29 & year == 105
 replace ND = 20.0 if sectornew==30 & year == 105
 replace ND = 65.2 if sectornew==31 & year == 105
 replace ND = 12.7 if sectornew==32 & year == 105
 replace ND = 29.7 if sectornew==33 & year == 105
 replace ND = 26.6 if sectornew==1 & year == 106
 replace ND = 26.5 if sectornew==2 & year == 106
 replace ND = 17.9 if sectornew==3 & year == 106
 replace ND = 23.4 if sectornew==4 & year == 106
 replace ND = 16.2 if sectornew==5 & year == 106
 replace ND = 20.5 if sectornew==6 & year == 106
 replace ND = 15.8 if sectornew==7 & year == 106
 replace ND = 16.0 if sectornew==8 & year == 106
 replace ND = 17.3 if sectornew==9 & year == 106
 replace ND = 14.9 if sectornew==10 & year == 106
 replace ND = 18.6 if sectornew==11 & year == 106 
 replace ND = 17.1 if sectornew==12 & year == 106
 replace ND = 17.6 if sectornew==13 & year == 106
 replace ND = 15.1 if sectornew==14 & year == 106
 replace ND = 20.0 if sectornew==15 & year == 106
 replace ND = 16.2 if sectornew==16 & year == 106
 replace ND = 18.1 if sectornew==17 & year == 106
 replace ND = 22.2 if sectornew==18 & year == 106
 replace ND = 20.4 if sectornew==19 & year == 106
 replace ND = 20.4 if sectornew==20 & year == 106
 replace ND = 24.6 if sectornew==21 & year == 106
 replace ND = 22.9 if sectornew==22 & year == 106
 replace ND = 22.4 if sectornew==23 & year == 106
 replace ND = 24.7 if sectornew==24 & year == 106
 replace ND = 25.7 if sectornew==25 & year == 106
 replace ND = 34.8 if sectornew==26 & year == 106
 replace ND = 46.8 if sectornew==27 & year == 106
 replace ND = 13.7 if sectornew==28 & year == 106
 replace ND = 26.0 if sectornew==29 & year == 106
 replace ND = 20.1 if sectornew==30 & year == 106
 replace ND = 65.3 if sectornew==31 & year == 106
 replace ND = 12.7 if sectornew==32 & year == 106
 replace ND = 30.4 if sectornew==33 & year == 106
 replace ND = 26.6 if sectornew==1 & year == 107
 replace ND = 27.1 if sectornew==2 & year == 107
 replace ND = 18.1 if sectornew==3 & year == 107
 replace ND = 24.0 if sectornew==4 & year == 107
 replace ND = 16.3 if sectornew==5 & year == 107
 replace ND = 20.8 if sectornew==6 & year == 107
 replace ND = 15.9 if sectornew==7 & year == 107
 replace ND = 16.1 if sectornew==8 & year == 107
 replace ND = 17.6 if sectornew==9 & year == 107
 replace ND = 14.9 if sectornew==10 & year == 107
 replace ND = 18.9 if sectornew==11 & year == 107
 replace ND = 17.1 if sectornew==12 & year == 107
 replace ND = 17.8 if sectornew==13 & year == 107
 replace ND = 15.2 if sectornew==14 & year == 107
 replace ND = 20.4 if sectornew==15 & year == 107
 replace ND = 16.4 if sectornew==16 & year == 107
 replace ND = 18.3 if sectornew==17 & year == 107
 replace ND = 22.7 if sectornew==18 & year == 107
 replace ND = 20.9 if sectornew==19 & year == 107
 replace ND = 20.9 if sectornew==20 & year == 107
 replace ND = 25.0 if sectornew==21 & year == 107
 replace ND = 23.2 if sectornew==22 & year == 107
 replace ND = 22.8 if sectornew==23 & year == 107
 replace ND = 24.8 if sectornew==24 & year == 107
 replace ND = 25.8 if sectornew==25 & year == 107
 replace ND = 36.3 if sectornew==26 & year == 107
 replace ND = 47.1 if sectornew==27 & year == 107
 replace ND = 13.7 if sectornew==28 & year == 107
 replace ND = 26.3 if sectornew==29 & year == 107
 replace ND = 20.6 if sectornew==30 & year == 107
 replace ND = 65.3 if sectornew==31 & year == 107
 replace ND = 12.7 if sectornew==32 & year == 107
 replace ND = 31.7 if sectornew==33 & year == 107

/*
* get the average lives to the differnt kiNDbp of investments
* mising values of the "share of net investments in total investments"; if miss-
* ing value: USE within firm average
*/

replace IPlant = 66 	if IPlant==1
replace IPlant = 0 		if IPlant==.
replace IIT = 7 		if IIT==1
replace IIT = 0 		if IIT==.
replace IProd = 15 		if IProd==1
replace IProd = 0 		if IProd==.
replace ITransp = 12 	if ITransp==1
replace ITransp = 0 	if ITransp==.

* generate variable NDbp__InvNebpt containing the avarage life of net investments
* Note: Each Combination of IPlant+IIT+IProd+ITransp gives an unique identification
* of which type of net investment actually took place

**Example:
* IPlant+IIT+IProd+ITransp==19 means that there were investments in IIT aNDbp ITransp
* aNDbp no investments in IPlant aNDbp IProd the mean of econ. lives of IIT aNDbp ITransp * == (7+12)/2 = 9.5

gen NDbp__InvNebpt = NDbp
replace NDbp__InvNebpt = 7 		if IPlant+IIT+IProd+ITransp==7		// IIT
replace NDbp__InvNebpt = 12 	if IPlant+IIT+IProd+ITransp==12		// ITransp
replace NDbp__InvNebpt = 15 	if IPlant+IIT+IProd+ITransp==15		// IProd
replace NDbp__InvNebpt = 66 	if IPlant+IIT+IProd+ITransp==66		// IPlant
replace NDbp__InvNebpt = 9.5 	if IPlant+IIT+IProd+ITransp==19		// IIT + ITransp
replace NDbp__InvNebpt = 11 	if IPlant+IIT+IProd+ITransp==22		// IIT + IProd
replace NDbp__InvNebpt = 13.5 	if IPlant+IIT+IProd+ITransp==27		// ITransp + IProd
replace NDbp__InvNebpt = 11.3 	if IPlant+IIT+IProd+ITransp==34		// IIT + ITransp + IProd
replace NDbp__InvNebpt = 36.5 	if IPlant+IIT+IProd+ITransp==73		// IIT + IPlant
replace NDbp__InvNebpt = 39 	if IPlant+IIT+IProd+ITransp==78		// ITransp + IPlant
replace NDbp__InvNebpt = 40.5 	if IPlant+IIT+IProd+ITransp==81		// IProd + IPlant
replace NDbp__InvNebpt = 28.3 	if IPlant+IIT+IProd+ITransp==85		// IIT + ITransp + IPlant
replace NDbp__InvNebpt = 29.3 	if IPlant+IIT+IProd+ITransp==88		// IIT + IProd + IPlant
replace NDbp__InvNebpt = 31 	if IPlant+IIT+IProd+ITransp==93		// ITransp + IProd + IPlant
replace NDbp__InvNebpt = 25 	if IPlant+IIT+IProd+ITransp==100	// IIT + ITransp + IProd + IPlant

*recode the Dummies as NDbp__InvNebpt now is created
replace IIT = 1 	if IIT == 7
replace IPlant = 1 	if IPlant==66
replace IProd = 1 	if IProd==15
replace ITransp = 1 if ITransp==12


***************************************************************************
* 3. multiply the replacement investment for each firm-year observation with the NDbp

* variables from the IAB Establishment Panel:
* inv_dK = percentage of net investments in total investment (0 - 100)
* First assumption on missing values:
**** there are numerous missing values in the variable inv_dK
**** the Researcher may decide to make assumptions about the missing data aNDbp impute
**** plausible values
**** one possibility is the following:
**** impute missing information on the share of net investments with the firm-
**** specific average if investments are known:
sort idnum year
by idnum: egen meaninv_dKbp = mean(inv_dK)
replace inv_dK = meaninv_dKbp if inv_dK == . & inv !=.
* END assumption on missing values in inv_dK

* generate level of net investments
gen InvNebp = inv*(inv_dK/100)
* generate level of net replacements
gen InvRebp = inv*(100-inv_dK)/100

****************************************************************************



****************************************************************************
* 4.1 Version I for estimators that rely mainly on between-firm information
* (e.g. OLS)

*4.1.1
**multiply replacements with economic lives for each year
gen K = InvRebp*NDbp

*4.1.2
**generate the within firm average over that value to obtain the starting
* value (SMA) based on T years
sort idnum year
by idnum: egen SMATbp = mean(K)
drop K

*4.1.3
*KTbp is the capital stock for Version I
**the capital stock for the first observation for each firm is set equal to SMATbp
gen KTbp = .
sort idnum year
replace KTbp = SMATbp if idnum[_n-1] != idnum

**start perpetual inventory from KTbp
*i. compute expected depreciation for the first year that the respective firm is
* in the data
sort idnum year
gen DEPTbp = .
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum
*ii. compute expected change in capital stock, given total investments aNDbp
* depreciation on last years capital aNDbp on half of this years net investments
gen dKTbpbp = .
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt))
sort idnum year
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum
*iii. the routine has to be repeated iteratively because for each year first
* depreciation aNDbp the capital stock has to be computed
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==. //works only if KTbp[_n-1] (== secoNDbp year) aNDbp NDbp[_n-1] exist
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==. //works only if investments are known, aNDbp DEPTbp aNDbp NDbp__InvNebpt exist
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum //writes KTbp into the next line if dKTbpbp exists
*SecoNDbp assumption on Missing Values
**a missing value in inv will eNDbp perpetual inventory even if there are valid
* observations in later periods
**the researcher may decide to impute KTbp for the year with missing inv in order to
* continue with perpetual inventory
****one possibility is to replace inv==. with inv==0 aNDbp continue with perpetual
* inventory; however, this is a strong assumption
****another possibility is to replace KTbp with KTbp[_n-1] aNDbp to continue
*****this assumption is more natural because it means to assume no changes in KTbp,
* while setting inv==0 means a decrease in KTbp
******My approach here: replace KTbp with previous year's KTbp if KTbp==. aNDbp inv==. aNDbp
* the same firm has valid information on inv in the next year
sort idnum year
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
// works not: if KTbp[_n-1] is missing, or if this is the last year of the firm,
// or if inv is missing in the next year
*ENDbp SecoNDbp assumption on missing values
*** then, perpetual inventory is repeated for each year of panel participation
*** while treating missing values as mentioned above, i.e.:
*** 3rd year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 4th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 5th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 6th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 7th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 8th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 9th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 10th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 11th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 12th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.

*** 13th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 14th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 15th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 16th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 17th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 18th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 19th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 20th year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 21st year of panel participation
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.

*** 22nd year of panel participation (vpe)
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 23rd year of panel participation (vpe)
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 24th year of panel participation (vpe)
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.
*** 25th year of panel participation (vpe)
sort idnum year
replace DEPTbp = KTbp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEPTbp==.
replace dKTbpbp = (InvRebp-DEPTbp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dKTbpbp==.
replace KTbp = KTbp[_n-1] + dKTbpbp if idnum[_n-1] == idnum & KTbp==.
replace KTbp = KTbp[_n-1] if idnum[_n-1] == idnum[_n+1] & KTbp==. & inv==. & inv[_n+1]!=.



****************************************************************************
* 4.2 Version II for estimators that use only within-firm information
* (e.g. Fixed Effects, First Differences, GMM-Diff, GMM-SYS)
*takes the arithmetic mean of the replacements of the first three years
*the firm is in the data as a starting value
*4.2.1
**multiply replacements with economic lives for each year
gen K = InvRebp*NDbp
*4.2.2
* generate SMA3bp (starting value with 3 years of support) for the secoNDbp
* observation of that firm
gen SMA3bp = .
sort idnum year
replace SMA3bp = (1/3)*(K[_n-1] + K + K[_n+1]) ///
if idnum[_n-2] != idnum & idnum[_n-1] == idnum[_n+1]
drop K
* insert SMA3bp into the first year of panel participation as capital stock
* value aNDbp in order to gain one observation for perpetual inventory
gen K3bp = .
sort idnum year
replace K3bp = SMA3bp[_n+1] if idnum[_n-1] != idnum & idnum == idnum[_n+1]
*4.2.3
*i. start perpetual inventory, analogue to KTbp, here compute depreciation
sort idnum year
gen DEP3bp = .
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum
*ii. compute expected change in capital stock, given total investments aNDbp
* depreciation on last years capital aNDbp on half of this years net investments
gen dK3bpbp = .
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt))
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum
*iii. the routine has to be repeated iteratively because for each year first
* depreciation aNDbp the capital stock has to be computed
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==. //works only if K3bp[_n-1] (== secoNDbp year) aNDbp NDbp[_n-1] exist
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.


//works only if investments are known, aNDbp DEP3bp aNDbp NDbp__InvNebpt exist
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum
//writes K3bp into the next line if dK3bpbp exists
*SecoNDbp assumption on Missing Values analogue to KTbp
sort idnum year
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=. //works not: if K3bp[_n-1] is missing, or if this is the last year of the
// firm, or if inv is missing in the next year
*** then, perpetual inventory is repeated for each year of panel participation
*** while treating missing values as mentioned above, i.e.:
*** 3rd year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 4th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 5th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 6th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 7th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 8th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 9th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 10th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 11th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 12th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 13th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 14th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 15th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 16th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 17th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 18th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 19th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 20th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 21st year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.

*** 22nd year of panel participation (vpe)
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 23rd year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 24th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.
*** 25th year of panel participation
sort idnum year
replace DEP3bp = K3bp[_n-1]/NDbp[_n-1] if idnum[_n-1] == idnum & DEP3bp==.
replace dK3bpbp = (InvRebp-DEP3bp)+InvNebp-(0.5*(InvNebp/NDbp__InvNebpt)) if dK3bpbp==.
replace K3bp = K3bp[_n-1] + dK3bpbp if idnum[_n-1] == idnum & K3bp==.
replace K3bp = K3bp[_n-1] if idnum[_n-1] == idnum[_n+1] & K3bp==. & inv==. & inv[_n+1]!=.

drop if idnum==.

ren sectornew wz08_2d
ren inv invest
ren NDbp ndbp
ren inv_dK invest_add 
ren  INo inv_kein
ren IPlant inv_geb 
ren IIT inv_edv 
ren IProd inv_prod 
ren ITransp inv_verk 

label var KTbp "KT approximated capital stock (use for OLS)"
label var K3bp "K3 approximated capital stock (use for Fixed effetcs regressions)"

save "$data\panel_v4.dta", replace

cap log close
