capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\fact1_`date'.log, replace
*-------------------------------------------------------------------------------
* FACT 1
*-------------------------------------------------------------------------------
use "$data\panel_v6_rbtadopt.dta", clear
cap est store clear
 cap est clear
 drop if D_robot==.
*-------------------------------------------------------------------------------
{ // Descriptives in text
*-------------------------------------------------------------------------------
* Share of robot users in manuf and non-manuf, Share of robot adopters (out of all the non-users) each year in manufand non-manuf
cd "$results"
svyset idnum [pw=hrf_robot]	// use weights from 2019 survey wave
** ROBOT USERS 
	tab D_robot if year==2018, m				// unweighted
	svy: tab D_robot if year==2018, ci			// weighted

* employed workers in manuf 
	tabstat ges_bes if D_robot==1 & year==2018 [w=hrf_robot], stats(sum) 
* total workforce Germany 
	tabstat ges_bes if  year==2018 [w=hrf_robot], stats(sum) format(%12.2f)

**  ROBOT ADOPTERS 
	unique idnum if D_robot_adoption==1 	
	tab D_robot_adoption if quer2019=="Q", m		
	tabstat D_robot_adoption if year==2018 & D_robot_adoption==1, stat(N mean) columns(statistics) by(manuf)
	*by manufacturing
	tab D_robot_adoption manuf if year==2018, row	
	tabstat idnum if D_robot_adoption_event==1 &manuf==1, stat(N) by(IAB_43) columns(statistics) varwidth(32) labelwidth(32)
}

{ // TABLE 2 
cap est store clear
cap est clear
xtset idnum year 

*** FACT 1:
* absorb < 1% categories into residual non-manufacturing: e.g. "consulting" and "other services":
replace IAB_43=0 if IAB_43==3 | IAB_43==20 | IAB_43==26 | IAB_43==29 | IAB_43==31 | IAB_43==32 ///
| IAB_43==33 | IAB_43==34 | IAB_43==35 | IAB_43==36 |  IAB_43==41 | IAB_43==42

* absorb also the industries with to few robot observations into the residual category 
tabstat D_robot_yearly if year==2018 & hrf_robot!=. & D_robot==1 [w=hrf_robot] , by(IAB_43) stats(N) not labelwidth(32) format(%9.0f)
replace IAB_43=0 if IAB==2 | IAB_43==23 |IAB_43==24 | IAB_43==25 | IAB_43==27 |IAB_43==28 | IAB_43==30 | ///
		IAB_43==37 | IAB_43==39 | IAB_43==40 | IAB_43==43 

* combine smaller categories, e.g. construction or retail/wholesale trade 
replace IAB_43=19 if IAB_43==18
replace IAB_43=22 if IAB_43==21

* residual manufacturing
replace IAB_43=5 if IAB_43==17 
replace IAB_43=. if IAB_43==17 

xtset idnum year

//// NEW LABELS FOR AGGREGATED CATEGORIES
label drop IAB_43
label define IAB_43	1 "agriculture/forestry" 4 "food/luxury" 5 "residual manufacturing (textiles/clothing, repair/installation)"6 "paper/print/wood" ///
	7 "chemical/pharmaceutical sector" 8 "plastics industry" 9 	"glass/ceramic" 10 "basic metals" ///
	11 "fabricated metal" 12 "electrical equipment" 13 "precision/optical equipment "14 "machinery and equipment" ///
	15 "motor vehicles" 16 "furniture/jewelry/sports/medical supplies"  ///
	19 "building/installation"  22  "wholesale trade and retail trade" ///
	38  "human health" ///
	0 "residual non-manufacturing" 200 "all manufacturing" 100 "all non-manufacturing"
label value IAB_43 IAB_43	

gen count_user= D_robot_yearly
gen count_D_robot_yearly= D_robot_yearly
gen uw_D_robot_yearly= D_robot_yearly

* by manufacturing unweighted 
preserve 
replace IAB_43=100 if manuf==0
replace IAB_43=200 if manuf==1
collapse (mean) uw_D_robot_yearly (sum) count_user (count) count_D_robot_yearly if year==2018 & hrf_robot!=., by(IAB_43)
save "$results\temp\temp1.dta", replace
restore

* by manufacturing weighted
preserve 
replace IAB_43=100 if manuf==0
replace IAB_43=200 if manuf==1
collapse (mean) D_robot_yearly  if year==2018 & hrf_robot!=. [aweight=hrf_robot], by(IAB_43)
merge 1:1 IAB_43 using ${results}\temp\temp1.dta 
save "$results\temp\temp2.dta", replace
restore

*by industry unweighted
preserve 
collapse (mean) uw_D_robot_yearly manuf (sum) count_user (count) count_D_robot_yearly if year==2018 & hrf_robot!=., by(IAB_43)
save "$results\temp\temp3.dta", replace
restore

*by industry weighted
collapse  (mean) D_robot_yearly if year==2018 & hrf_robot!=. [aweight=hrf_robot], by(IAB_43)
merge 1:1 IAB_43 using ${results}\temp\temp3.dta

* only robot users counted
gsort - D_robot_yearly
append using ${results}\temp\temp2.dta
drop if IAB_43==.
drop _merge
foreach x in D_robot_yearly uw_D_robot_yearly {
replace `x'=`x'*100
replace `x'=round(`x',.01)
}
ren D_robot_yearly weighted
ren uw_D_robot_yearly unweighted
ren count_user N_user_2018
ren count_D_robot_yearly N

* generate sector order for table 1
egen order=rank(weighted) 
replace order=order+100 if manuf==1
replace order=200 if IAB_43==200
replace order=100 if IAB_43==200
replace order=0 if IAB_43==0
gsort - order
}

export excel using "$results\fact1.xlsx",  sheetreplace firstrow(variables) sheet("fact1")
drop N_user_2018 manuf order

export excel using "$results\fact1.xlsx",  sheetreplace firstrow(variables) sheet("fact1_table1")

cap log close



