capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\fact2_`date'.log, replace
*-------------------------------------------------------------------------------
* FACT 2
*-------------------------------------------------------------------------------
cd "$results\temp" 	
use "$data\panel_v6_rbtadopt.dta", clear									
xtset idnum year 

preserve 
keep if year==2018 & robots!=. & robots!=0 & manuf==1
keep idnum year robots D_robot D_robot_adoption D_robot_yearly new2018_robots hrf_robot ges_bes
bys idnum: gen dens=robots*1000/ges_bes

** unweighted part2 (top 10 centiles)
	sort robots, stable
	bysort robots: egen rbt_rank=rank(robots), unique
	quantiles robots, gen(q_top) n(100)
	replace q_top=. if q_top<=90
	quantiles q_top, gen(help) n(5)
	* count observations:
	tabstat idnum if help!=. &robots!=., by(help) stats(N)
	tabstat robots if robots!=., by(help) stats(mean N)
	bys help: egen avg_robots_help=mean(robots) if help!=.
	bys help: egen avg_density_help=mean(robots*1000/ges_bes) if help!=.
	bys help: egen avg_density_help_2=mean(ges_bes) if help!=.
	bys help: replace avg_density_help_2=avg_robots_help*1000/avg_density_help_2
	sort q_top
	br idnum q_top help avg_robots_help avg_dens*
	format avg_density_help %12.0f
	format avg_density_help_2 %12.0f
	format avg_robots_help %12.0f
	
	keep avg_robots_help  hel* avg_dens*
	replace help=help*2
	replace help=help+90
	duplicates drop
	keep *help*

	set scheme s2color
			grstyle init 
			grstyle set color RdYlBu,  n(5) reverse

	sort help		
	twoway 	bar avg_robots_help help , barwidth(.65)   || scatter avg_robots_help help, pstyle(p2)  msymbol(none)  ///	
				mlabgap(.5) mlab(avg_robots_help) mlabcolor(black) mlabsize(small)  mlabpos(12) ///
				aspectratio(.8, placement(top)) pstyle(p1) ///
				ytitle( " " " ", size(medsmall)) graphr(color(white)) plotr(color(white)) ///
				xtitle(" " "centiles of robot distribution", size(medsmall)) xlabel(92(2)100) ysc( log) ylabel(10 100 1000,angle(0)) ///
				legend(on label(1 "average number of robots per plant") order(1) rows(2))  ///
				name(part2,replace) saving(part2,replace)			
* robot density
	twoway 	bar avg_density_help_2 help , barwidth(.65) fintensity(inten20) pstyle(p1) || scatter avg_density_help_2 help, pstyle(p2)  msymbol(none)  ///	
				mlabgap(.5) mlab(avg_density_help_2) mlabcolor(black) mlabsize(small)  mlabpos(12) ///
				aspectratio(.8, placement(top)) ///
				ytitle( " " " ", size(medsmall)) graphr(color(white)) plotr(color(white)) ///
				xtitle(" " "centiles of robot distribution", size(medsmall)) xlabel(92(2)100) ysc( r(0 120)) ylabel(0 50 100,angle(0)) ///
				legend(on label(1 "average robot density per plant") order( 1) rows(2))  ///
				name(dens_part2,replace) saving(dens_part2,replace)			
restore 

** weighted part 2 (top 10 centiles)
preserve 
	keep if year==2018 & robots!=. & robots!=0 & manuf==1
	keep idnum year robots D_robot D_robot_adoption D_robot_yearly new2018_robots hrf_robot ges_bes
	expand hrf_robot
	sort idnum
	sort robots, stable
	bysort robots: egen rbt_rank=rank(robots), unique
	quantiles robots, gen(q_top) n(100)
	replace q_top=. if q_top<=90
	quantiles q_top, gen(help) n(5)
	bys help: egen avg_robots_help=mean(robots) if help!=.
	bys help: egen avg_density_help=mean(robots*1000/ges_bes) if help!=.
	bys help: egen avg_density_help_2=mean(ges_bes) if help!=.
	bys help: replace avg_density_help_2=avg_robots_help*1000/avg_density_help_2 if help!=.
	sort q_top
	br idnum q_top help avg_robots_help avg_dens*
	format avg_density_help %12.0f
	format avg_density_help_2 %12.0f
	format avg_robots_help %12.0f

	keep avg_robots_help  hel* avg_dens*
	replace help=help*2
	replace help=help+90
	duplicates drop
	keep *help*

	set scheme s2color
			grstyle init 
			grstyle set color RdYlBu,  n(5) reverse

	sort help		
	twoway 	bar avg_robots_help help,  barwidth(.65)   || scatter avg_robots_help help, pstyle(p2)  msymbol(none)  ///	
				mlabgap(.5) mlab(avg_robots_help) mlabcolor(black) mlabsize(small)  mlabpos(12) ///
				aspectratio(.8, placement(top)) pstyle(p1) ///
				ytitle( " " " ", size(medsmall)) graphr(color(white)) plotr(color(white)) ///
				xtitle(" " "centiles of robot distribution", size(medsmall)) xlabel(92(2)100) ysc( log) ylabel(10 50 150,angle(0)) ///
				legend(on label(1 "average number of robots per plant") order(1) rows(2))  ///
				name(part2_weighted,replace) saving(part2_weighted,replace)			

* robot density
	twoway 	bar avg_density_help_2 help , barwidth(.65) fintensity(inten20) pstyle(p1) || scatter avg_density_help_2 help, pstyle(p2)  msymbol(none)  ///	
				mlabgap(.5) mlab(avg_density_help_2) mlabcolor(black) mlabsize(small)  mlabpos(12) ///
				aspectratio(.8, placement(top)) ///
				ytitle( " " " ", size(medsmall)) graphr(color(white)) plotr(color(white)) ///
				xtitle(" " "centiles of robot distribution", size(medsmall)) xlabel(92(2)100) ysc( r(0 100)) ylabel(0 50 100 ,angle(0)) ///
				legend(on label(1 "average robot density per plant") order(1) rows(2))  ///
				name(dens_part2_weighted,replace) saving(dens_part2_weighted,replace)			

****************
* Excel Export *
****************
format avg_robots_help %9.0f
estpost tabstat avg_robots_help, col(stats)  by(help)  
ren help centiles
keep avg_robots_help centiles
export excel using "$results\fact2.xls", sheet("Fact2B") sheetreplace firstrow(variables)

restore 

** unweighted part 1 (deciles)
preserve 
	keep if year==2018 & robots!=. & robots!=0 & manuf==1
	keep idnum year robots D_robot D_robot_adoption D_robot_yearly new2018_robots hrf_robot ges_bes
	sort robots, stable
	bysort robots: egen rbt_rank=rank(robots), unique
	* group plants in deciles and centiles by number of robots
	quantiles robots, gen(decile_robots) n(10)
	* calculate average number of robots per decile 
	bys decile_robots: egen avg_robots_dec=mean(robots)
	replace avg_robots_dec= round(avg_robots_dec,1)
		* count observations:
		tabstat idnum if robots!=., by(decile_robots) stats(N)
		tabstat avg_robots_dec if robots!=., by(decile_robots) stats(mean N)
	bys decile_robots: egen avg_density_dec=mean(robots*1000/ges_bes) 
	bys decile_robots: egen avg_density_dec_2=mean(ges_bes) 
	bys decile_robots: replace avg_density_dec_2=avg_robots_dec*1000/avg_density_dec_2
	format avg_density_dec %12.0f
	format avg_density_dec_2 %12.0f
	format avg_robots_dec %12.0f
	
	keep avg_robots decile* avg_dens*

	set scheme s2color
			grstyle init 
			grstyle set color RdYlBu,  n(5) reverse
*robots
	twoway 	bar avg_robots_dec decile_robots , barwidth(.65) || scatter avg_robots_dec decile_robots, ///
				pstyle(p2)  msymbol(none)  ///	
				mlabgap(.5) mlab(avg_robots_dec) mlabcolor(black) mlabsize(small)  mlabpos(12) xsc(r(1 10)) xlabel(1(1)10) ///
				ytitle( "number of robots" " ", size(medsmall)) graphr(color(white)) plotr(m(zero) color(white)) ///
				xtitle(" " "deciles of robot distribution", size(medsmall)) ysc(log r(0.9 500)) ylabel(1 10 100 500,angle(0))  ///
				legend(on label(1 "average number of robots per plant") order(1) rows(2)) aspectratio(1.5, placement(bottom))   ///
				name(part1,replace) saving(part1,replace)
* robot density
	twoway 	bar avg_density_dec_2 decile_robots, barwidth(.65) fintensity(inten20) pstyle(p1)  ///
				|| scatter avg_density_dec_2 decile_robots, ///
				pstyle(p2)  msymbol(none)  ///	
				mlabgap(.5) mlab(avg_density_dec_2) mlabcolor(black) mlabsize(small)  mlabpos(12) /// 
				xsc(r(1 10)) xlabel(1(1)10) ///
				ytitle( "number of robots per 1000 employees" " ", size(medsmall)) graphr(color(white)) plotr(m(zero) color(white)) ///
				xtitle(" " "deciles of robot distribution", size(medsmall)) ysc(r(0 100)) ylabel(0 50 100,angle(0))  ///
				legend(on label(1 "average robot density per plant")  order( 1) ///
				rows(2))    ///		//aspectratio(1.5, placement(bottom))
				name(dens_part1,replace) saving(dens_part1,replace)
restore 
		
** weighted part 1 (deciles)
preserve 

keep if year==2018 & robots!=. & robots!=0  & manuf==1
	keep idnum year robots D_robot D_robot_adoption D_robot_yearly new2018_robots hrf_robot ges_bes
	expand hrf_robot
	sort robots, stable
	bysort robots: egen rbt_rank=rank(robots), unique
	* group plants in deciles by number of robots
	quantiles robots, gen(decile_robots) n(10)
	* calculate average number of robots per decile 
	bys decile_robots: egen avg_robots_dec=mean(robots)
	replace avg_robots_dec= round(avg_robots_dec,1)
	bys decile_robots: egen avg_density_dec=mean(robots*1000/ges_bes) 
	bys decile_robots: egen avg_density_dec_2=mean(ges_bes) 
	bys decile_robots: replace avg_density_dec_2=avg_robots_dec*1000/avg_density_dec_2
	format avg_density_dec %12.0f
	format avg_density_dec_2 %12.0f
	format avg_robots_dec %12.0f
	
	
	keep avg_robots*  decile* avg_dens*

	set scheme s2color
		grstyle init 
		grstyle set color RdYlBu,  n(5) reverse

*robots
	twoway 	bar avg_robots_dec decile_robots , barwidth(.65) || scatter avg_robots_dec decile_robots, ///
				pstyle(p2)  msymbol(none)  ///	
				mlabgap(.5) mlab(avg_robots_dec) mlabcolor(black) mlabsize(small)  mlabpos(12) xsc(r(1 10)) xlabel(1(1)10) ///
				ytitle( "number of robots" " ", size(medsmall)) graphr(color(white)) plotr(m(zero) color(white)) ///
				xtitle(" " "deciles of robot distribution", size(medsmall)) ysc(log r(0.9 50)) ylabel(1 10 50 ,angle(0))  ///
				legend(on label(1 "average number of robots per plant") order(1) rows(2)) aspectratio(1.5, placement(bottom))   ///
			name(part1_weighted,replace) saving(part1_weighted,replace)

* robot density 
	twoway 	bar avg_density_dec_2 decile_robots, barwidth(.65) fintensity(inten20) pstyle(p1)  ///
				|| scatter avg_density_dec_2 decile_robots, ///
				pstyle(p2)  msymbol(none)  ///	
				mlabgap(.5) mlab(avg_density_dec_2) mlabcolor(black) mlabsize(small)  mlabpos(12) /// 
				xsc(r(1 10)) xlabel(1(1)10) ///
				ytitle( "number of robots per 1000 employees" " ", size(medsmall)) graphr(color(white)) plotr(m(zero) color(white)) ///
				xtitle(" " "deciles of robot distribution", size(medsmall)) ysc( r(0 100)) ylabel(1 50 100,angle(0))  ///
				legend(on label(1 "average robot density per plant")  order( 1) ///
				rows(2))   ///
				name(dens_part1_weighted,replace) saving(dens_part1_weighted,replace)

****************
* Excel Export *
****************
format avg_robots_dec %9.0f
estpost tabstat avg_robots_dec, col(stats)  by(decile_robots)  
* Excel export
keep decile_robots avg_robots_dec
duplicates drop
export excel using "$results\fact2.xls", sheet("Fact2A") sheetreplace firstrow(variables)
restore 
	

* skewness of robot distribution		
	grc1leg "part1" "part2", graphr(color(white)) plotr(color(white)) name(manuf_uw,replace)
	graph export "$results\stylizedfacts_figure2a_skewness_manuf_uw.png", replace width(1200) height(900)

	grc1leg "part1_weighted" "part2_weighted", graphr(color(white)) plotr(color(white)) name(manuf_w,replace)
	graph export "$results\stylizedfacts_figure2a_skewness_manuf_w.png", replace width(1200) height(900)


* skewness of robot density		 
	grc1leg "dens_part1" , graphr(color(white)) plotr(color(white)) name(dens_manuf_uw,replace)
	graph export "$results\stylizedfacts_figure2a_dens_manuf_uw.png", replace width(1200) height(900)
	
	grc1leg "dens_part1_weighted", graphr(color(white)) plotr(color(white)) name(dens_manuf_w,replace)
	graph export "$results\stylizedfacts_figure2a_dens_manuf_w.png", replace width(1200) height(900)


* ADDITIONAL INFO IN TEXT
use "$data\panel_v6_rbtadopt.dta", clear								
xtset idnum year 
keep if year==2018 & robots!=. & robots!=0 
keep idnum year robots D_robot D_robot_adoption D_robot_yearly new2018_robots hrf_robot ges_bes IAB_43 manuf
tabstat robots if year==2018, stats( p10 p50 p90 mean N) by(IAB_43) not labelwidth(32)

sort robots, stable
quantiles robots, gen(centile_robots) n(100)

preserve
keep if manuf==0
quantiles robots, gen(decile_robots) n(10)

tabstat robots if year==2018 & decile_robots==10  [w=hrf_robot], stats(mean)  // non adopters mean in top decile
tabstat robots if year==2018 [w=hrf_robot], stats(N p50) format(%9.2f) 		 // non adopters median
restore 

keep if year==2018 & robots!=. & robots!=0 
keep idnum year robots D_robot D_robot_adoption D_robot_yearly new2018_robots hrf_robot ges_bes IAB_43
tabstat robots if year==2018, stats( p10 p50 p90 mean N) by(IAB_43) not labelwidth(32)
expand hrf_robot
sort robots, stable
quantiles robots, gen(centile_robots) n(100)


* ROBOT USE AND ROBOT INSTALLATIONS IN 2018 BY TOP5 AND TOP10 % OF ROBOT USERS:
bys centile_robots: egen avg_robots_centile=mean(robots)
bys centile_robots: egen avg_new2018robots_centile=mean(new2018_robots)

total robots if year==2018 & centile_robots>95 &centile_robots<. // robot stock in 2018 owned by top5% largest plants 
total new2018_robots if year==2018 & centile_robots>95 &centile_robots<.//  share of new robot installations for top5% largest robot plants 
	
cap log close	




