capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\fact3_`date'.log, replace
*-------------------------------------------------------------------------------
* FACT 3
*-------------------------------------------------------------------------------
*AGENDA: 
*	3a. Decomposition of robot growth (extensive)
*	3b. Decomposition of robot growth (intensive)
*	APPENDIX GRAPHS (3a: lower and upper bound 2014)
cd "$results\temp" 	
 
*-------------------------------------------------------------------------------
{ //  DATA PREPARATION 
*-------------------------------------------------------------------------------
use "$data\panel_v6_rbtadopt.dta", clear										

xtset idnum year 
cap est store clear
cap est clear
keep if D_robot!=. 	// drop observations if robot question was not answered (less than 1% is dropped)

* AGGREGATE INDUSTRIES (slightly more aggregated than for fact 1)
tabstat D_robot_yearly if year==2018 & hrf_robot!=. [w=hrf_robot] , by(IAB_43) stats(mean ) not labelwidth(32) format(%9.4f)
* absorb < 1% categories into residual non-manufacturing: e.g. "consulting" and "other services":
replace IAB_43=0 if IAB_43==3 | IAB_43==20 | IAB_43==26 | IAB_43==29 | IAB_43==31 | IAB_43==32 ///
| IAB_43==33 | IAB_43==34 | IAB_43==35 | IAB_43==36 |  IAB_43==41 | IAB_43==42

* absorb also the industries with to few robot observations into the residual category // new VP 05/07/2022
tabstat D_robot_yearly if year==2018 & hrf_robot!=. & D_robot==1 [w=hrf_robot] , by(IAB_43) stats(N) not labelwidth(32) format(%9.0f)
replace IAB_43=0 if IAB_43==2 | IAB_43==23 |IAB_43==24 | IAB_43==25 | IAB_43==27 |IAB_43==28 | IAB_43==30 | ///
		IAB_43==37 | IAB_43==39 | IAB_43==40 | IAB_43==43 | IAB_43==18 | IAB_43==19

* combine smaller categories, e.g. retail/wholesale trade 
replace IAB_43=22 if IAB_43==21

* residual manufacturing:  textiles + precision/optical equipment  (7 users) + repair/installation
replace IAB_43=5 if IAB_43==17 
replace IAB_43=5 if IAB_43==13
replace IAB_43=5 if IAB_43==7

xtset idnum year

* NEW LABELS FOR AGGREGATED CATEGORIES
label drop IAB_43
label define IAB_43	1 "agriculture/forestry" 4 "food/luxury" 5 "residual manufacturing" /// // residual includes: (textiles, repair/installation, precision/optical equipment, chemical/pharmaceutical)"
	6 "paper/print/wood" ///
	8 "plastics" 9 	"glass/ceramic" 10 "basic metals" ///
	11 "fabricated metal" 12 "electrical equipment" 14 "machinery and equipment" ///
	15 "motor vehicles" 16 "furniture/jewelry/sports/medical"  ///
	22  "wholesale/retail trade" ///
	38  "human health" ///
	0 "residual non-manufacturing" 200 "all manufacturing" 100 "all non-manufacturing"
label value IAB_43 IAB_43	

save "$data\panel_v7_rbtadopt.dta", replace 									// use also aggregated sectors in fact 4.  

* for fact 3: 
keep if year==2014 | year==2018
}

*-------------------------------------------------------------------------------
{ // PART I: UNWEIGHTED 
*-------------------------------------------------------------------------------
*3a. DECOMPOSITION OF ROBOT GROWTH (EXTENSIVE MARGIN)
*-------------------------------------------------------------------------------
preserve
*** FURTHER PREPARATION FOR FIGURE 3a:
xtset idnum year 
* calculate shares by industries:
	*** 2018 shares
	bys IAB_43: egen user_share_2018= mean(D_robot_yearly) if year==2018  & D_robot_yearly!=.
			replace user_share_2018= user_share_2018*100
	bys manuf: egen user_share_2018_aggr= mean(D_robot_yearly) if year==2018  & D_robot_yearly!=.
			replace user_share_2018_aggr= user_share_2018_aggr*100
	sum user_share*

	*** 2014: there are missings in D_robot_yearly. We use a basic imputation here:
		tab D_robot_yearly year, m
		* generate dummy for plants with 2014 missing robot stock:
			sort idnum year
			bys idnum: gen D_missing=1 if D_robot_yearly==. & year==2014 & D_robot==1
		* generate dummy for plants with 2018 robot use (condition for imputation rule):
			sort idnum year
			bys idnum: gen D_use2018=1 if D_robot_yearly==1 & year==2018 & D_robot==1
			xtset idnum year
			sort idnum year
				bys idnum: replace D_use2018=D_use2018[_n+1] if D_use2018==. & year==2014
		* calculate number of users in 2014 
		xtset idnum year
			bys IAB_43: egen using_plants=count(idnum) if year==2014 & D_robot_yearly==1 & D_use2018==1
			bys IAB_43: egen all_plants=count(idnum) if year==2014 & D_robot_yearly!=. & D_use2018==1
			bys manuf: egen using_plants_aggr=count(idnum) if year==2014 & D_robot_yearly==1 & D_use2018==1
			bys manuf: egen all_plants_aggr=count(idnum) if year==2014 & D_robot_yearly!=. & D_use2018==1
			
		* calculate probabilities in 2014 (share of plants that report the robot stock in 2014)
			bys IAB_43: gen prob_2014= using_plants/all_plants if year==2014  & D_robot_yearly!=. & D_use2018==1
			bys manuf: gen prob_2014_aggr=  using_plants/all_plants if year==2014 & D_robot_yearly!=. & D_use2018==1
			sum prob_2014*
		
		* copy certain calculated values for IAB_43: 
			xtset idnum year
			foreach x in prob_2014 using_plants all_plants user_share_2018 {
			cap drop help 
			bys IAB_43: egen help=min(`x') 
			bys IAB_43: replace `x'= help if `x'==.
			}	
				
		* copy certain calculated values for manuf: 
			xtset idnum year
			foreach x in prob_2014_aggr user_share_2018_aggr {
			cap drop help 
			bys manuf: egen help=min(`x') 
			bys manuf: replace `x'= help if `x'==.			
			}	
		* generate user count variable for excel export later 
			bys IAB_43: egen count_user= sum(D_robot)  if robots!=. & year==2014
			bys manuf: egen count_user2= sum(D_robot)  if robots!=. & year==2014

keep idnum IAB_43 robots user_share* D_robot_yearly D_robot year prob* D_missing manuf all_plants* using_plants* count_user*

* calculate new share in 2014 based on all plants (including imputed values for D_robot_yearly)
		keep if year==2014
		bys IAB_43: gen user_share_2014_new= using_plants/all_plants*user_share_2018 if year==2014 
		bys manuf: gen user_share_2014_new_aggr= using_plants_aggr/all_plants_aggr*user_share_2018_aggr if year==2014 
			

keep IAB_43 year user_share_2018* user_share_2014_new_aggr user_share_2014_new  manuf  count_user*
duplicates drop
sort IAB_43
keep if year==2014
drop if  (user_share_2014_new==. & IAB_43!=40) | (user_share_2014_new_aggr==. & IAB_43!=40) | user_share_2018==.
replace user_share_2014_new=0 if IAB_43==40
replace user_share_2014_new_aggr=0 if IAB_43==40

* insert 2 additional obs for aggregate categories:	
	set obs 21
	replace IAB_43=100 if IAB_43==.
	replace manuf=0 if IAB_43==100
	set obs 22
	replace IAB_43=200 if IAB_43==.
	replace manuf=1 if IAB_43==200
	replace year=2014 if year==.

* include the aggregate level information:
sort manuf 
foreach x in user_share_2018_aggr user_share_2014_new_aggr count_user2 {
cap drop help 
by manuf: egen help=min(`x') 
by manuf: replace `x'= help if `x'==.
}
replace user_share_2018=user_share_2018_aggr if IAB_43==100 | IAB_43==200
replace user_share_2014_new=user_share_2014_new_aggr if IAB_43==100 | IAB_43==200
replace count_user= count_user2 if IAB_43==100 | IAB_43==200

* setting order of sectors for new graph:  
	egen help1= rank(user_share_2014_new) if manuf==1 & year==2014 & IAB_43!=200, unique 
		replace help1=15 if IAB_43==200
		replace help1=help1+100 if manuf==1 & year==2014
		replace help1=0 if help1==. & year==2014
	egen help2= rank(user_share_2014_new) if manuf==0 & IAB_43!=0 & year==2014 & IAB_43!=100, unique 
		replace help2=6 if help2==. & IAB_43==100
		replace help2=0 if help2==. & year==2014 
	gen help3= help1+help2 if year==2014
	duplicates drop
	tab help3
	egen sector_order= rank(help3), unique 
	sort sector_order
	

set scheme s2color
		grstyle init 
		grstyle set color RdYlBu,  n(6) reverse

*** GRAPH 3a
	twoway 	rbar user_share_2014_new user_share_2018 sector_order, barw(.1) ylabel(none ,nogrid ang(h)) ///
				 yline(5.5, lpattern(dot) lcolor(black))  ///
				 yline(4.5, lpattern(dot) lcolor(black)) ///
				 yline(17.7, lpattern(dot) lcolor(black)) ///
				 yline(16.5, lpattern(dot) lcolor(black)) ///
				 graphr(color(white)) plotr(color(white)) horizontal  sort(sector_order) pstyle(p2)  || ///
			scatter sector_order user_share_2014_new , msymbol(D) pstyle(p1)  || ///
			scatter sector_order user_share_2018  ,  pstyle(p4) msymbol(O)   ///
				mlabgap(2) mlab(IAB_43) mlabcolor(black) mlabsize(vsmall)  mlabpos(3) ylabel(none ,nogrid) ///
				xtitle("Share of robot users (%)", size(small)) ysc(off) title(" ", span size(small)) ///
				ytitle(" ", size(vsmall)) xla(, ang(h) labs(small) )  legend(on symxsize(13) label(3 " ")  ///
				label (3 "2018") label(2 "2014") label(1 " ") ///
				 span size(small) order( 2 3  ) rows(1))  xscale(range(0(5)35)) 			///
				graphr(color(white)) plotr(color(white)) name(stylizedfacts_figure3a, replace) saving(stylizedfacts_figure3a, replace)
	graph export "$results\stylizedfact_3a.png", replace width(1200) height(900)

* Excel export
	estpost tabstat user_share_2014_new user_share_2018 , col(variables)  by(sector_order) 
	cap drop help* year user_share_2018_aggr user_share_2014_new_aggr 
	order user_share_2018, after(user_share_2014_new)
	gsort - sector_order
	export excel using "$results\fact3.xlsx",  sheetreplace firstrow(variables) sheet("fact3a_unweighted")

restore 



*-------------------------------------------------------------------------------
* 3b. DECOMPOSITION OF ROBOT GROWTH (INTENSIVE MARGIN) 
*-------------------------------------------------------------------------------
/*	3. decomposition of robot growth: we want to create a chart to show the decomposition of robot growth by industry and for manuf and non-manuf as a whole. For each industry/sector, we want to calculate the percentage change in the total # of robots from 2014 to 2018. Just focus on the plants that reported robot stock continuously. Then decompose this change into:
	(1) share of change in robots purchased by existing robot users in 2014; 
	(2) share of robots purchased by the robot adopters (adopted from 2015 to 2018) in the first year of adoption; 
	(3) share of robots purchased by the robot adopters in subsequent years after adoption. For example, if we have the following data for robot stock:
               2014   2015   2016   2017   2018
Plant 1:    5         5         7         7         10
Plant 2:    0         1         1         1         2

Then for category (1), # = 10-5=5
Category (2), # = 1
Category (3), # = 2-1=1

If (2) or (3) looks negligible, we may collapse them into one category later. The idea is to visualize how important the intensive margin is. 
*/
cap drop help

*** DEFINITIONS AND BASIC DESCRIPTIVES ***
* ROBOT PURCHASING FIRMS DEFINITION: in our sample, firms are robot purchasers if deliveries in 2018 is positive, or if robot stock over time increased: 
	gen D_robot_purchase=.
	bys idnum: replace D_robot_purchase=1 if new2018_robots>0 & new2018_robots<.
	* also a robot purchasing firm, if in 2018 the robot stock is higher than for any previous year:
		bys idnum: replace D_robot_purchase=1 if robots<.  & D_robot==1 & ///
		((robots>L.robots & L.robots!=.) | (robots>L2.robots & L2.robots!=.) | (robots>L3.robots & L3.robots!=.) | /// 
		(robots>L4.robots & L4.robots!=.) )
	* non-purchasers are all robot using firms that did report no robot use at all or a constant robot stock over time:
		bys idnum: replace D_robot_purchase=0 if D_robot==0
		bys idnum: replace D_robot_purchase=0 if robots<. & D_robot==1 & ///
		((robots<=L.robots & L.robots!=.) | (robots<=L2.robots & L2.robots!=.) | (robots<=L3.robots & L3.robots!=.) | /// 
		(robots<=L4.robots & L4.robots!=.) )
		
* calculate change per plant:
	bys idnum: gen rbt_change= robots-L4.robots if robots!=. & year==2018
	label var rbt_change "absolute change of robot stock from 2014 to 2018 at plant level"

 
preserve 
*** DATA PREPARATION FOR GROWTH DECOMPOSITION FIGURE ***
	keep if D_robot==1	// keep only plants that answered the robot question with "yes"
	* keep only plants that answer the 2014 AND 2018 intensive margin
		keep if year==2014 | year== 2018
		xtset idnum year 
		bys idnum: gen help1=1 if robots!=. & year==2014 	// create dummy for non-missing 2014 number of robots
		bys idnum: egen help=min(help1) 
		bys idnum: replace help1= help if help1==.
		*bys idnum (year): carryforward help1, replace
		drop if help1==.	// keep only if 2014 number of robots is non-missing
		bys idnum: gen help2=1 if robots!=. & year==2018	// create dummy for non-missing 2014 number of robots
		bys idnum: egen help3=total(help2) 
		drop if help3==0	// keep only if 2018 number of robots is non-missing
		*br robots idnum year IAB_43 help*
		drop help*
	* how many plants remain? 504.
	unique idnum

keep idnum year IAB_43 robots D_robot_adoption D_robot manuf new2018_robots founded ges_bes D_robot_yearly 	// keep only relevant variables
xtset idnum year

* calculate robot stock in 2014 and 2018 per sector for all remaining robot users and subsample of adopters:
		forvalues i=14(4)18 {
		bys IAB_43 year: egen rbt_stock20`i'= total(robots) if year==20`i'		// all users
		bys manuf year: egen rbt_stock20`i'_aggr= total(robots) if year==20`i'		// all users
		bys IAB_43 year: egen rbt_stock20`i'_adopt= total(robots) if robots!=. & year==20`i' & D_robot_adoption==1 // subsample adopters
		replace rbt_stock2014_adopt=0
		bys manuf year: egen rbt_stock20`i'_adopt_aggr= total(robots) if robots!=. & year==20`i' & D_robot_adoption==1 // subsample adopters
		replace rbt_stock2014_adopt_aggr=0
		}
* generate user count variable for excel export later 
		bys IAB_43: egen count_user= sum(D_robot)  if robots!=. & year==2014
		tabstat  count_user, by(IAB_43) stats(mean sum N )

* copy information to all years:
	foreach x in rbt_stock2014 rbt_stock2018 rbt_stock2014_adopt rbt_stock2018_adopt count_user   {
	cap drop help 
	bys IAB_43: egen help= min(`x') 
	bys IAB_43: replace `x'=help if `x'==.	
	}

* copy aggregate information to all years:
	foreach x in rbt_stock2014_aggr rbt_stock2018_aggr rbt_stock2014_adopt_aggr rbt_stock2018_adopt_aggr {
	cap drop help 
	bys manuf: egen help= min(`x') 
	bys manuf: replace `x'=help if `x'==.	
	}

duplicates drop

* calculate change of robot stock per sector for all users and subsample of adopters:
		bys IAB_43: gen rbt_purchases= rbt_stock2018-rbt_stock2014		// all users
		label var rbt_purchases "total robot purchases between 2014 and 2018 per industry (IAB_43)"
		bys manuf: gen rbt_purchases_aggr= rbt_stock2018_aggr-rbt_stock2014_aggr		// all users

		bys IAB_43: gen rbt_purchases_adopt= rbt_stock2018_adopt-rbt_stock2014_adopt	// only adopters
		label var rbt_purchases_adopt "total robot purchases by adopters between 2014 and 2018 per industry (IAB_43)"
		bys manuf: gen rbt_purchases_adopt_aggr= rbt_stock2018_adopt_aggr-rbt_stock2014_adopt_aggr	// only adopters

* copy information to all years:
	foreach x in rbt_purchases rbt_purchases_adopt  {
	cap drop help 
	bys IAB_43: egen help= min(`x') 
	bys IAB_43: replace `x'=help if `x'==.	
	}

* copy information to all years:
	foreach x in rbt_purchases_aggr rbt_purchases_adopt_aggr  {
	cap drop help 
	bys manuf: egen help= min(`x') 
	bys manuf: replace `x'=help if `x'==.	
	}

* calculate overall growth in robot stock: 
	bys IAB_43: gen rbt_growth= rbt_purchases/rbt_stock2014*100 if year==2018
	label var rbt_growth "growth in robot stock between 2014 and 2018 per industry (IAB_43) in %"
	bys manuf: gen rbt_growth_aggr= rbt_purchases_aggr/rbt_stock2014_aggr*100 if year==2018
		* count observations:
		tabstat idnum if rbt_growth!=., by(IAB_43) stats(N)
		tabstat idnum if year==2018 &  D_robot_yearly!=. , by(IAB_43) stats(N)
		tabstat idnum if year==2014 &  D_robot_yearly==1 , by(IAB_43) stats(N)
		
* calculate growth in robot stock by adopters:
	bys IAB_43 D_robot_adoption: gen rbt_growth_adopt= rbt_purchases_adopt/(rbt_stock2014)*100 if  year==2018 
	bys manuf D_robot_adoption: gen rbt_growth_adopt_aggr= rbt_purchases_adopt_aggr/(rbt_stock2014_aggr)*100 if  year==2018 
	*bys IAB_43: gen rbt_growth_users= rbt_growth_adopt if D_robot_adoption==0
	sort IAB_43, stable
	replace rbt_growth_adopt=. if D_robot_adoption==0
	replace rbt_growth_adopt_aggr=. if D_robot_adoption==0
	label var rbt_growth_adopt "growth in robot stock per industry (2014-2018) accounted for by adopters in %"
	*label var rbt_growth_users "growth in robot stock per industry (2014-2018) accounted for by users in %"

* copy information to all years:
	foreach x in rbt_growth rbt_growth_adopt count_user {
	cap drop help 
	bys IAB_43: egen help= min(`x') 
	bys IAB_43: replace `x'=help if `x'==.	
	}
* copy aggregate information to all years:
	foreach x in  rbt_growth_aggr rbt_growth_adopt_aggr  {
	cap drop help 
	bys manuf: egen help= min(`x') 
	bys manuf: replace `x'=help if `x'==.	
	}

* keep only aggregated sector level information:
keep IAB_43 year rbt_growth* rbt_purchase* manuf count_user*
keep if year==2018	
duplicates drop
sort IAB_43
unique IAB_43
keep if (rbt_growth_adopt!=.& rbt_purchases_adopt!=.  & rbt_growth_adopt_aggr!=. & rbt_purchases_adopt_aggr!=. & year==2018) 

* insert 2 additional obs for aggregate categories:	
set obs 20
replace IAB_43=100 if IAB_43==.
replace manuf=0 if IAB_43==100
set obs 21
replace IAB_43=200 if IAB_43==.
replace manuf=1 if IAB_43==200 
replace year=2018 if year==.
bys manuf: egen count_user2=total(count_user)
replace count_user=count_user2 if IAB_43==200 |  IAB_43==100

* copy aggregate information to all years:
	foreach x in  rbt_growth_aggr rbt_growth_adopt_aggr {
	cap drop help 
	bys manuf: egen help= min(`x') 
	bys manuf: replace `x'=help if `x'==.	
	}
	
* include the aggregate level information:
sort IAB_43
replace rbt_growth=rbt_growth_aggr if IAB_43==100 | IAB_43==200
replace rbt_growth_adopt=rbt_growth_adopt_aggr if IAB_43==100 | IAB_43==200
duplicates drop


drop if IAB_43==100 & rbt_growth_adopt_aggr==.
duplicates drop
* setting order of sectors for new graph:  
	egen help1= rank(rbt_growth_adopt) if manuf==1 & year==2018 & IAB_43!=200, unique 
		replace help1=15 if IAB_43==200
		replace help1=help1+100 if manuf==1 & year==2018
		replace help1=0 if help1==. & year==2018
	egen help2= rank(rbt_growth_adopt) if manuf==0 & IAB_43!=0 & year==2018 & IAB_43!=100, unique 
		replace help2=6 if help2==. & IAB_43==100
		replace help2=0 if help2==. & year==2018 
	gen help3= help1+help2 if year==2018
	duplicates drop
	tab help3
	egen sector_order= rank(help3), unique 
	sort sector_order

set scheme s2color
		grstyle init 
		grstyle set color RdYlBu,  n(6) reverse

gen zero=0

format rbt_growth_adopt %9.0f
format rbt_growth %9.0f

sort sector_order

keep IAB_43 manuf rbt_gr* sector_order count_user zero 
duplicates drop 

*** NEW FIGURE 3b:
twoway 	rbar zero rbt_growth sector_order if IAB_43!=100 & IAB_43!=200, barw(.7) pstyle(p1) horizontal ///
				ytitle(" ", size(vsmall)) xla(, ang(h) labs(small) )  || ///
		rbar zero rbt_growth_adopt sector_order if IAB_43!=100 & IAB_43!=200,  barw(.7) pstyle(p2) horizontal ///
		yline(17.5,lpattern(dot) lcolor(black)) ///
		yline(16.5,lpattern(dot) lcolor(black)) ///
		yline(5.5,lpattern(dot) lcolor(black)) ///
		yline(4.5,lpattern(dot) lcolor(black)) || ///
		rbar zero rbt_growth sector_order if IAB_43==100 | IAB_43==200, barw(.7) pstyle(p1) horizontal ///
				ytitle(" ", size(vsmall)) xla(, ang(h) labs(small) )  || ///
		rbar zero rbt_growth_adopt sector_order if IAB_43==100 | IAB_43==200 ,  barw(.7) pstyle(p2) horizontal  || ///
		scatter sector_order rbt_growth,  pstyle(p1)  msymbol(none)  ///	
				mlabgap(.5) mlab(rbt_growth) mlabcolor(black) mlabsize(vsmall)  mlabpos(3) ylabel(none ,nogrid) xtitle(" ", size(vsmall)) || ///
		scatter sector_order zero if IAB_43!=300 , msymbol(none)  ///	
				mlabgap(2) mlab(IAB_43) mlabcolor(black) mlabsize(vsmall)  mlabpos(9) ylabel(none ,nogrid) ///
				xtitle("Growth of robot stock per sector in % (2014-2018)", size(small))  graphr(color(white)) plotr(color(white)) ///
				ytitle(" ", size(vsmall)) xla(, ang(h) labs(small) )  legend(on symxsize(6) label(2 "robot adopters")  ///
				label (1 "robot users")   ///
				 size(small) order(2 1) rows(1)) aspectratio(.75, placement(right)) 			///
				graphr(color(white)) plotr(color(white)) name(stylizedfacts_figure3b, replace) saving(stylizedfacts_figure3b, replace)

	graph export "$results\stylizedfact_3b.png", replace width(1200) height(900)

* Excel Export 
keep IAB_43 manuf rbt_gr* sector_order count_user
order rbt_growth_aggr rbt_growth_adopt_aggr, before(rbt_growth)
drop if IAB_43==300 
gsort -sector_order
export excel using "$results\fact3.xlsx",  sheetreplace firstrow(variables) sheet("fact3b_unweighted")
restore
}

*-------------------------------------------------------------------------------
{ // PART II: WEIGHTED 
*-------------------------------------------------------------------------------
* 3a. DECOMPOSITION OF ROBOT GROWTH (EXTENSIVE MARGIN)
*-------------------------------------------------------------------------------
*** FIGURE 3a: INCREASE IN NUMBER OF ROBOT USERS BETWEEN 2014 AND 2018:
preserve

xtset idnum year 
* calculate shares by industries:
*** 2018 shares
	gen help_1=D_robot_yearly*hrf_robot if year==2018 // multiply robot use with weight
	bys IAB_43: egen help_2=sum(help_1) if year==2018 & hrf_robot!=. & D_robot_yearly!=. // all users 2018 per sector
	bys IAB_43: egen help_3=sum(hrf_robot) if hrf_robot!=. & year==2018 & D_robot_yearly!=. // all plants 2018 that answered robot question in 2019 survey per sector
	bys IAB_43: gen user_share_2018= help_2/help_3 if year==2018 
			replace user_share_2018= user_share_2018*100
	bys manuf: egen help_4=sum(help_1) if year==2018 & hrf_robot!=. // all users 2018 per sector
	bys manuf: egen help_5=sum(hrf_robot) if hrf_robot!=. & year==2018 // all plants 2018 that answered robot question in 2019 survey per sector
	bys manuf: gen user_share_2018_aggr= help_4/help_5 if year==2018 & hrf_robot!=.
			replace user_share_2018_aggr= user_share_2018_aggr*100
	drop help*
	sum user_share*

*** 2014: there are 99 missings in D_robot_yearly. We use a basic imputation here:
		* generate dummy for plants with 2014 missing robot stock:
			sort idnum year
			bys idnum: gen D_missing=1 if D_robot_yearly==. & year==2014 & D_robot==1
		* generate dummy for plants with 2018 robot use (condition for imputation rule):
			sort idnum year
			bys idnum: gen D_use2018=1 if D_robot_yearly==1 & year==2018 & D_robot==1
			xtset idnum year
			sort idnum year
				bys idnum: replace D_use2018=D_use2018[_n+1] if D_use2018==. & year==2014
				bys idnum: replace hrf_robot=hrf_robot[_n+1] if hrf_robot==. & year==2014
				
		* calculate share of users in 2014, conditional on robot use in 2018
		xtset idnum year
			bys IAB_43: egen using_plants=sum(D_robot_yearly*hrf_robot) if year==2014  & D_use2018==1 & D_robot_yearly!=.
			bys IAB_43: egen all_plants=sum(hrf_robot) if year==2014 & D_robot_yearly!=. & hrf_robot!=. & D_use2018==1 
			bys manuf: egen using_plants_aggr=sum(D_robot_yearly*hrf_robot) if year==2014  & D_use2018==1 &D_robot_yearly!=.
			bys manuf: egen all_plants_aggr=sum(hrf_robot) if year==2014 & D_robot_yearly!=. & hrf_robot!=. & D_use2018==1 
			
		* copy certain calculated values for IAB_43: 
			xtset idnum year
			foreach x in using_plants all_plants user_share_2018 {
			cap drop help 
			bys IAB_43: egen help=min(`x') 
			bys IAB_43: replace `x'= help if `x'==.
			}	
		* copy certain calculated values for manuf: 
			xtset idnum year
			foreach x in user_share_2018_aggr  {
			cap drop help 
			bys manuf: egen help=min(`x') 
			bys manuf: replace `x'= help if `x'==.			
			}	
		
		* check number of observations 
			tabstat user_share_2018 if D_robot_yearly!=. & year==2018, by(IAB_43) stats(N) labelwidth(32) format(%9.0f)
			tabstat user_share_2018 if D_robot_yearly==1 & year==2018, by(IAB_43) stats(N) labelwidth(32) format(%9.0f)
			* generate user count variable for excel export later 
			bys IAB_43: egen count_user= sum(D_robot)  if robots!=. & year==2014
			bys manuf: egen count_user2= sum(D_robot)  if robots!=. & year==2014
				
		br idnum IAB_43 robots user_share* D_robot_yearly D_robot year  if D_robot==1
		keep idnum IAB_43 robots user_share* D_robot_yearly D_robot year D_missing manuf all_plants* using_plants*
		* calculate new share in 2014 based on all plants (including imputed values for D_robot_yearly)
		keep if year==2014
			bys IAB_43: gen user_share_2014_new= using_plants/all_plants*user_share_2018 if year==2014 
			bys manuf: gen user_share_2014_new_aggr= using_plants_aggr/all_plants_aggr*user_share_2018_aggr if year==2014 
			
		* copy certain calculated values for manuf: 
			xtset idnum year
			foreach x in user_share_2014_new_aggr {
			cap drop help 
			bys manuf: egen help=min(`x') 
			bys manuf: replace `x'= help if `x'==.			
			}	
				
		
keep IAB_43 year user_share_2018* user_share_2014_new_aggr user_share_2014_new  manuf  
duplicates drop
sort IAB_43
keep if year==2014
drop if  (user_share_2014_new==. & IAB_43!=40) | (user_share_2014_new_aggr==. & IAB_43!=40) | user_share_2018==.
replace user_share_2014_new=0 if IAB_43==40

* insert 2 additional obs for aggregate categories:	
set obs 21
replace IAB_43=100 if IAB_43==.
replace manuf=0 if IAB_43==100
set obs 22
replace IAB_43=200 if IAB_43==.
replace manuf=1 if IAB_43==200
replace year=2014 if year==.

* include the aggregate level information:
sort manuf 
* copy certain calculated values for manuf: 
		foreach x in user_share_2018_aggr user_share_2014_new_aggr {
		cap drop help 
		bys manuf: egen help=min(`x') 
		bys manuf: replace `x'= help if `x'==.			
		}	
replace user_share_2018=user_share_2018_aggr if IAB_43==100 | IAB_43==200
replace user_share_2014_new=user_share_2014_new_aggr if IAB_43==100 | IAB_43==200


* setting order of sectors for new graph:  
*	egen help1= rank(user_share_2014) if manuf==1 & year==2014 & IAB_43!=200, unique 
	egen help1= rank(user_share_2014_new) if manuf==1 & year==2014 & IAB_43!=200, unique 
		replace help1=15 if IAB_43==200
		replace help1=help1+100 if manuf==1 & year==2014
		replace help1=0 if help1==. & year==2014
*		egen help2= rank(user_share_2014) if manuf==0 & IAB_43!=0 & year==2014 & IAB_43!=100, unique 
	egen help2= rank(user_share_2014_new) if manuf==0 & IAB_43!=0 & year==2014 & IAB_43!=100, unique 
		replace help2=6 if help2==. & IAB_43==100
		replace help2=0 if help2==. & year==2014 
	gen help3= help1+help2 if year==2014
	duplicates drop
	tab help3
	egen sector_order= rank(help3), unique 
	sort sector_order
	

tabstat user_share_2014_new user_share_2018 , by(IAB_43) stats(mean ) not labelwidth(32) format(%9.2f)

*** NEW GRAPH 3a
	twoway 	rbar user_share_2014_new user_share_2018 sector_order, barw(.1) ylabel(none ,nogrid ang(h)) ///
				 yline(5.5, lpattern(dot) lcolor(black))  ///
				 yline(4.5, lpattern(dot) lcolor(black)) ///
				 yline(17.5, lpattern(dot) lcolor(black)) ///
				 yline(16.5, lpattern(dot) lcolor(black)) ///
				 graphr(color(white)) plotr(color(white)) horizontal  sort(sector_order) pstyle(p2)  || ///
			scatter sector_order user_share_2014_new , msymbol(D) pstyle(p1)  || ///
			scatter sector_order user_share_2018  ,  pstyle(p4) msymbol(O)   ///
				mlabgap(2) mlab(IAB_43) mlabcolor(black) mlabsize(vsmall)  mlabpos(3) ylabel(none ,nogrid) ///
				xtitle("Share of robot users (%)", size(small)) ysc(off) title(" ", span size(small)) ///
				ytitle(" ", size(vsmall)) xla(, ang(h) labs(small) )  legend(on symxsize(13) label(3 " ")  ///
				label (3 "2018") label(2 "2014") label(1 " ") ///
				 span size(small) order( 2 3  ) rows(1))  xscale(range(0(5)30)) 			///
				graphr(color(white)) plotr(color(white)) name(stylizedfacts_figure3a_weighted, replace) saving(stylizedfacts_figure3a_weighted, replace)
	/* note("Data source: IAB Establishment Panel (2019)." ///
				"Notes:  Shares of robot users are calculated per year and industry based on 3300 manufacturing plants." ///
				"            Due to 17% missings in the reported 2014 robot stock, upper and lower bounds are presented." , size(vsmall)) /// */

	graph export "$results\stylizedfact_3a_weighted.png", replace width(1200) height(900)

* Excel export
keep sector_order IAB_43 user_share_2014_new  user_share_2018  
gsort - sector_order
export excel using "$results\fact3.xlsx",  sheetreplace firstrow(variables) sheet("fact3a_weighted")

restore 

*-------------------------------------------------------------------------------
* 3b. DECOMPOSITION OF ROBOT GROWTH (INTENSIVE MARGIN) 
*-------------------------------------------------------------------------------
/*	3. decomposition of robot growth: we want to create a chart to show the decomposition of robot growth by industry and for manuf and non-manuf as a whole. For each industry/sector, we want to calculate the percentage change in the total # of robots from 2014 to 2018. Just focus on the plants that reported robot stock continuously. Then decompose this change into:
	(1) share of change in robots purchased by existing robot users in 2014; 
	(2) share of robots purchased by the robot adopters (adopted from 2015 to 2018) in the first year of adoption; 
	(3) share of robots purchased by the robot adopters in subsequent years after adoption. For example, if we have the following data for robot stock:
               2014   2015   2016   2017   2018
Plant 1:    5         5         7         7         10
Plant 2:    0         1         1         1         2

Then for category (1), # = 10-5=5
Category (2), # = 1
Category (3), # = 2-1=1

If (2) or (3) looks negligible, we may collapse them into one category later. The idea is to visualize how important the intensive margin is. 
*/
cap drop help

preserve 
	 
*** DATA PREPARATION FOR GROWTH DECOMPOSITION FIGURE ***
	keep if D_robot==1	// keep only plants that answered the robot question with "yes"
	* keep only plants that answer the 2014 AND 2018 intensive margin
		keep if year==2014 | year== 2018
		xtset idnum year 
		bys idnum: gen help1=1 if robots!=. & year==2014 	// create dummy for non-missing 2014 number of robots
		bys idnum (year): carryforward help1, replace
		drop if help1==.	// keep only if 2014 number of robots is non-missing
		bys idnum: gen help2=1 if robots!=. & year==2018	// create dummy for non-missing 2014 number of robots
		bys idnum: egen help3=total(help2) 
		drop if help3==0	// keep only if 2018 number of robots is non-missing
		*br robots idnum year IAB_43 help*
		drop help*

keep idnum year IAB_43 robots D_robot_adoption D_robot manuf new2018_robots founded ges_bes hrf_robot	// keep only relevant variables

* for weighted version we assume that we can apply the 2018 weights to the 2014 wave:
			xtset idnum year
				bys idnum: replace hrf_robot=hrf_robot[_n+1] if hrf_robot==. & year==2014

	* calculate robot stock in 2014 and 2018 per sector for all remaining robot users and subsample of adopters:
		forvalues i=14(4)18 {
		bys IAB_43 year: egen rbt_stock20`i'= total(robots*hrf_robot) if year==20`i'		// all users
		bys manuf year: egen rbt_stock20`i'_aggr= total(robots*hrf_robot) if year==20`i'		// all users
		bys IAB_43 year: egen rbt_stock20`i'_adopt= total(robots*hrf_robot) if robots!=. & year==20`i' & D_robot_adoption==1 // subsample adopters
		replace rbt_stock2014_adopt=0
		bys manuf year: egen rbt_stock20`i'_adopt_aggr= total(robots*hrf_robot) if robots!=. & year==20`i' & D_robot_adoption==1 // subsample adopters
		replace rbt_stock2014_adopt_aggr=0
		}
* copy information to all years:
	foreach x in rbt_stock2014 rbt_stock2018 rbt_stock2014_adopt rbt_stock2018_adopt {
	cap drop help 
	bys IAB_43: egen help= min(`x') 
	bys IAB_43: replace `x'=help if `x'==.	
	}

* copy aggregate information to all years:
	foreach x in rbt_stock2014_aggr rbt_stock2018_aggr rbt_stock2014_adopt_aggr rbt_stock2018_adopt_aggr {
	cap drop help 
	bys manuf: egen help= min(`x') 
	bys manuf: replace `x'=help if `x'==.	
	}


* check duplicates!
duplicates drop
	* calculate change of robot stock per sector for all users and subsample of adopters:
		bys IAB_43: gen rbt_purchases= rbt_stock2018-rbt_stock2014		// all users
		label var rbt_purchases "total robot purchases between 2014 and 2018 per industry (IAB_43)"
		bys manuf: gen rbt_purchases_aggr= rbt_stock2018_aggr-rbt_stock2014_aggr		// all users
		bys IAB_43: gen rbt_purchases_adopt= rbt_stock2018_adopt-rbt_stock2014_adopt	// only adopters
		label var rbt_purchases_adopt "total robot purchases by adopters between 2014 and 2018 per industry (IAB_43)"
		bys manuf: gen rbt_purchases_adopt_aggr= rbt_stock2018_adopt_aggr-rbt_stock2014_adopt_aggr	// only adopters

* copy information to all years:
	foreach x in rbt_purchases rbt_purchases_adopt {
	cap drop help 
	bys IAB_43: egen help= min(`x') 
	bys IAB_43: replace `x'=help if `x'==.	
	}

* copy information to all years:
	foreach x in rbt_purchases_aggr rbt_purchases_adopt_aggr  {
	cap drop help 
	bys manuf: egen help= min(`x') 
	bys manuf: replace `x'=help if `x'==.	
	}

	* calculate overall growth in robot stock: 
	bys IAB_43: gen rbt_growth= rbt_purchases/rbt_stock2014*100 if year==2018
	label var rbt_growth "growth in robot stock between 2014 and 2018 per industry (IAB_43) in %"
	bys manuf: gen rbt_growth_aggr= rbt_purchases_aggr/rbt_stock2014_aggr*100 if year==2018

	* calculate growth in robot stock by adopters:
	bys IAB_43 D_robot_adoption: gen rbt_growth_adopt= rbt_purchases_adopt/(rbt_stock2014)*100 if  year==2018 
	bys manuf D_robot_adoption: gen rbt_growth_adopt_aggr= rbt_purchases_adopt_aggr/(rbt_stock2014_aggr)*100 if  year==2018 
	sort IAB_43, stable
	replace rbt_growth_adopt=. if D_robot_adoption==0
	replace rbt_growth_adopt_aggr=. if D_robot_adoption==0
	label var rbt_growth_adopt "growth in robot stock per industry (2014-2018) accounted for by adopters in %"

* copy information to all years:
	foreach x in rbt_growth rbt_growth_adopt {
	cap drop help 
	bys IAB_43: egen help= min(`x') 
	bys IAB_43: replace `x'=help if `x'==.	
	}
* copy aggregate information to all years:
	foreach x in  rbt_growth_aggr rbt_growth_adopt_aggr {
	cap drop help 
	bys manuf: egen help= min(`x') 
	bys manuf: replace `x'=help if `x'==.	
	}

* keep only aggregated sector level information:
keep IAB_43 year rbt_growth* rbt_purchase* manuf 
keep if year==2018	
duplicates drop
sort IAB_43
keep if (rbt_growth_adopt!=.& rbt_purchases_adopt!=.  & rbt_growth_adopt_aggr!=. & rbt_purchases_adopt_aggr!=. & year==2018) 

* insert 2 additional obs for aggregate categories:	
set obs 20
replace IAB_43=100 if IAB_43==.
replace manuf=0 if IAB_43==100
set obs 21
replace IAB_43=200 if IAB_43==.
replace manuf=1 if IAB_43==200 | IAB_43==300
replace year=2018 if year==.


* copy aggregate information to all years:
	foreach x in  rbt_growth_aggr rbt_growth_adopt_aggr {
	cap drop help 
	bys manuf: egen help= min(`x') 
	bys manuf: replace `x'=help if `x'==.	
	}
	
* include the aggregate level information:
sort IAB_43
replace rbt_growth=rbt_growth_aggr if IAB_43==100 | IAB_43==200
replace rbt_growth_adopt=rbt_growth_adopt_aggr if IAB_43==100 | IAB_43==200
duplicates drop

drop if IAB_43==100 & rbt_growth_adopt_aggr==.
duplicates drop
* setting order of sectors for new graph:  
	egen help1= rank(rbt_growth_adopt) if manuf==1 & year==2018 & IAB_43!=200, unique 
		replace help1=15 if IAB_43==200
		replace help1=help1+100 if manuf==1 & year==2018
		replace help1=0 if help1==. & year==2018
	egen help2= rank(rbt_growth_adopt) if manuf==0 & IAB_43!=0 & year==2018 & IAB_43!=100, unique 
		replace help2=6 if help2==. & IAB_43==100
		replace help2=0 if help2==. & year==2018 
	gen help3= help1+help2 if year==2018
	duplicates drop
	tab help3
	egen sector_order= rank(help3), unique 
	sort sector_order


gen zero=0

format rbt_growth_adopt %9.0f
format rbt_growth %9.0f

sort sector_order
tabstat rbt_growth if IAB_43!=300, by(IAB_43) stats(mean ) labelwidth(32) format(%9.1f) not
*drop if rbt_purchases==.
*** NEW FIGURE 3b:
twoway 	rbar zero rbt_growth sector_order if IAB_43!=100 & IAB_43!=200, barw(.7) pstyle(p1) horizontal ///
				ytitle(" ", size(vsmall)) xla(, ang(h) labs(small) )  || ///
		rbar zero rbt_growth_adopt sector_order if IAB_43!=100 & IAB_43!=200,  barw(.7) pstyle(p2) horizontal ///
		yline(17.5,lpattern(dot) lcolor(black)) ///
		yline(16.5,lpattern(dot) lcolor(black)) ///
		yline(5.5,lpattern(dot) lcolor(black)) ///
		yline(4.5,lpattern(dot) lcolor(black)) || ///
		rbar zero rbt_growth sector_order if IAB_43==100 | IAB_43==200, barw(.7) pstyle(p1) horizontal ///
				ytitle(" ", size(vsmall)) xla(, ang(h) labs(small) )  || ///
		rbar zero rbt_growth_adopt sector_order if IAB_43==100 | IAB_43==200 ,  barw(.7) pstyle(p2) horizontal  || ///
		scatter sector_order rbt_growth,  pstyle(p1)  msymbol(none)  ///	
				mlabgap(.5) mlab(rbt_growth) mlabcolor(black) mlabsize(vsmall)  mlabpos(3) ylabel(none ,nogrid) xtitle(" ", size(vsmall)) || ///
		scatter sector_order zero if IAB_43!=300 , msymbol(none)  ///	
				mlabgap(2) mlab(IAB_43) mlabcolor(black) mlabsize(vsmall)  mlabpos(9) ylabel(none ,nogrid) ///
				xtitle("Growth of robot stock per sector in % (2014-2018)", size(small))  graphr(color(white)) plotr(color(white)) ///
				ytitle(" ", size(vsmall)) xla(, ang(h) labs(small) )  legend(on symxsize(6) label(2 "robot adopters")  ///
				label (1 "robot users")   ///
				 size(small) order(2 1) rows(1)) aspectratio(.75, placement(right)) ///
				graphr(color(white)) plotr(color(white)) name(figure3b_weighted, replace) saving(figure3b_weighted, replace)
			
	graph export "$results\stylizedfact_3b_weighted.png", replace width(1200) height(900)

	
* Excel Export
keep IAB_43 manuf rbt_gr* sector_order
order rbt_growth_aggr rbt_growth_adopt_aggr, before(rbt_growth)
drop if IAB_43==300 
gsort -sector_order
export excel using "$results\fact3.xlsx",  sheetmodify firstrow(variables) sheet("fact3b_weighted")
restore
}

*-------------------------------------------------------------------------------
{ // APPENDIX GRAPHS
cap drop help

preserve
*-------------------------------------------------------------------------------
* APPENDIX 3a. DECOMPOSITION OF ROBOT GROWTH (EXTENSIVE MARGIN, w) 
*-------------------------------------------------------------------------------
/* in order to calculate upper and lower bounds of shares:
		A: firms never used robots
		B: firms with 2014 number missing, but used robots
		C: firms with 2014 number zero, but used robots
		D: firms with 2014 number positive

		B1: firms with 2018 number missing, but used robots
		C1: firms with 2018 number zero, but used robots
		D1: firms with 2018 number positive

		blue dot = D/(A+C+D) 
		D/(A+B+C+D) -- lower bound
		B+D/(A+B+C+D) -- upper bound

		red dot = D1/(A+C1+D1) -- answer=yes for extensive margin / full sample
*/

* for weighted version we assume that we can apply the 2018 weights to the 2014 wave:
			xtset idnum year
				bys idnum: replace hrf_robot=hrf_robot[_n+1] if hrf_robot==. & year==2014

* calculate shares by industries:
*** 2018 shares
	* 2018  (all plants with robots_2018=. and D_robot==1 are assumed to have positive number of robots in 2018)
	bys year: gen help2=D_robot_yearly if  year==2018
	replace help2=1 if D_robot_yearly==.  & year==2018
	replace help2=0 if D_robot==0 & year==2018
	tab help2 year // now for 616 plants the information is available
	gen help_1=help2*hrf_robot if year==2018 // multiply robot use with weight
	bys IAB_43: egen help_2=sum(help_1) if year==2018 & hrf_robot!=. & help2!=. // all users 2018 per sector
	bys IAB_43: egen help_3=sum(hrf_robot) if hrf_robot!=. & year==2018 & help2!=. 
	bys IAB_43: gen user_share_2018= help_2/help_3 if year==2018 
	bys manuf: egen help_4=sum(help_1) if year==2018 & hrf_robot!=. // all users 2018 per sector
	bys manuf: egen help_5=sum(hrf_robot) if hrf_robot!=. & year==2018 // all plants 2018 that answered robot question in 2019 survey per sector
	bys manuf: gen user_share_2018_aggr= help_4/help_5 if year==2018 & hrf_robot!=.
	replace user_share_2018=user_share_2018*100
	replace user_share_2018_aggr=user_share_2018_aggr*100
	drop help*
*** 2014 shares:
	* 2014 lower bound (all plants with robots_2014=. and D_robot==1 are assumed to have 0 robots in 2014)
	bys year: gen help=D_robot_yearly if  year==2014
	replace help=0 if D_robot_yearly==.& D_robot==1 & year==2014
	replace help=0 if D_robot==0 & year==2014
	tab help year // now for all 616 plants the information is available
	bys IAB_43: egen users_2014_lb= sum(help*hrf_robot) if year==2014   & help!=.
	bys IAB_43: egen plants_2014_lb= sum(hrf_robot) if year==2014   & D_robot_yearly!=.
	bys IAB_43: gen user_share_2014_lb= users_2014_lb/plants_2014_lb if year==2014   & D_robot_yearly!=.
	replace user_share_2014_lb=user_share_2014_lb*100
	bys manuf: egen users_2014_lb_aggr= sum(help*hrf_robot) if year==2014   & help!=.
	bys manuf: egen plants_2014_lb_aggr= sum(hrf_robot) if year==2014   & D_robot_yearly!=.
	bys manuf: gen user_share_2014_lb_aggr= users_2014_lb_aggr/plants_2014_lb_aggr if year==2014   & D_robot_yearly!=.
	replace user_share_2014_lb_aggr=user_share_2014_lb_aggr*100

	* 2014 upper bound (all plants with robots_2014=. and D_robot==1 are assumed to have positive number of robots in 2014)
	bys year: gen help2=D_robot_yearly if year==2014
	replace help2=1 if D_robot_yearly==. & D_robot==1 & year==2014
	replace help2=0 if D_robot==0 & year==2014
	tab help2 year // now for 616 plants the information is available
	bys IAB_43: egen users_2014_ub= sum(help2*hrf_robot) if year==2014   & help2!=.
	bys IAB_43: egen plants_2014_ub= sum(hrf_robot) if year==2014   & D_robot_yearly!=. & hrf_robot!=.
	bys IAB_43: gen user_share_2014_ub= users_2014_ub/plants_2014_ub if year==2014   & D_robot_yearly!=.
	replace user_share_2014_ub=user_share_2014_ub*100

	* copy certain calculated values for IAB_43: 
	xtset idnum year
	foreach x in user_share_2018 user_share_2014_lb user_share_2014_ub {
	cap drop help 
	bys IAB_43: egen help=min(`x') 
	bys IAB_43: replace `x'= help if `x'==.
	}	

	bys manuf: egen users_2014_ub_aggr= sum(help2*hrf_robot) if year==2014   & help2!=.
	bys manuf: egen plants_2014_ub_aggr= sum(hrf_robot) if year==2014   & D_robot_yearly!=. & hrf_robot!=.
	bys manuf: gen user_share_2014_ub_aggr= users_2014_ub_aggr/plants_2014_ub_aggr if year==2014   & D_robot_yearly!=.
	replace user_share_2014_ub_aggr=user_share_2014_ub_aggr*100

	* copy certain calculated values for manuf: 
	xtset idnum year
	foreach x in user_share_2014_lb_aggr user_share_2014_ub_aggr user_share_2018_aggr {
	cap drop help 
	bys manuf: egen help=min(`x') 
	bys manuf: replace `x'= help if `x'==.			
	}	

	br idnum IAB_43 robots user_share* D_robot_yearly D_robot year  if D_robot_yearly==.
		drop help*

keep IAB_43 year user_share_201* manuf
duplicates drop
sort IAB_43
drop if  user_share_2018_aggr==.
drop if user_share_2014_lb==.
drop if user_share_2014_ub==.
drop if user_share_2014_lb_aggr==.
drop if user_share_2014_ub_aggr==.

keep if year==2018
* insert 2 additional obs for aggregate categories:	
set obs 21
replace IAB_43=100 if IAB_43==.
replace manuf=0 if IAB_43==100
set obs 22
replace IAB_43=200 if IAB_43==.
replace manuf=1 if IAB_43==200
replace year=2018 if year==.

* copy certain calculated values for manuf: 
	foreach x in user_share_2014_lb_aggr user_share_2014_ub_aggr user_share_2018_aggr {
	cap drop help 
	bys manuf: egen help=min(`x') 
	bys manuf: replace `x'= help if `x'==.			
	}	

* include the aggregate level information:
sort manuf
replace user_share_2018=user_share_2018_aggr if IAB_43==100 | IAB_43==200
replace user_share_2014_lb=user_share_2014_lb_aggr if IAB_43==100 | IAB_43==200
replace user_share_2014_ub=user_share_2014_ub_aggr if IAB_43==100 | IAB_43==200


* setting order of sectors for new graph:  
	egen help1= rank(user_share_2014_ub) if manuf==1 & year==2018 & IAB_43!=200, unique 
		replace help1=15 if IAB_43==200
		replace help1=help1+100 if manuf==1 & year==2018
		replace help1=0 if help1==. & year==2018
	egen help2= rank(user_share_2014_ub) if manuf==0 & IAB_43!=0 & year==2018 & IAB_43!=100, unique 
		replace help2=6 if help2==. & IAB_43==100
		replace help2=0 if help2==. & year==2018 
	gen help3= help1+help2 if year==2018
	duplicates drop
	tab help3
	egen sector_order= rank(help3), unique 
	sort sector_order
	

tabstat user_share_2014_lb user_share_2014_ub user_share_2018 , by(IAB_43) stats(mean) not labelwidth(32) format(%9.2f)
*** NEW GRAPH 3a
	twoway 	rbar user_share_2014_ub user_share_2018 sector_order, barw(.1) ylabel(none ,nogrid ang(h)) ///
				 yline(5.5, lpattern(dot) lcolor(black))  ///
				 yline(4.5, lpattern(dot) lcolor(black)) ///
				 yline(17.7, lpattern(dot) lcolor(black)) ///
				 yline(16.5, lpattern(dot) lcolor(black)) ///
				 graphr(color(white)) plotr(color(white)) horizontal  sort(sector_order) pstyle(p2)  || ///
			rbar user_share_2014_lb user_share_2014_ub sector_order, barw(.05) ylabel(none ,nogrid ang(h)) ///
				 graphr(color(white)) plotr(color(white)) horizontal  sort(sector_order) pstyle(p2) lpattern(dot) || ///
			scatter sector_order user_share_2014_ub  , msymbol(D) pstyle(p1)  || ///
			scatter sector_order user_share_2014_lb  , msymbol(Dh) pstyle(p1)  || ///
			scatter sector_order user_share_2018  ,  pstyle(p4) msymbol(O)   ///
				mlabgap(2) mlab(IAB_43) mlabcolor(black) mlabsize(vsmall)  mlabpos(3) ylabel(none ,nogrid) ///
				xtitle("Share of robot users (%)", size(small)) ysc(off) title(" ", span size(small)) ///
				ytitle(" ", size(vsmall)) xla(, ang(h) labs(small) )  legend(on symxsize(13) label(3 "2014 - upper bound")  ///
				label (5 "2018") label(4 "2014 - lower bound") label(1 "growth ") ///
				 span size(small) order( 4 3 5 ) rows(1))  xscale(range(0(5)30)) 			///
				graphr(color(white)) plotr(color(white)) name(stylizedfact3a_appendix_weighted, replace) ///
				saving(stylizedfact3a_appendix_weighted, replace)


	graph export "$results\stylizedfact_3a_APPENDIX_weighted.png", replace width(1200) height(900)

keep sector_order IAB_43 user_share_2014_lb user_share_2014_ub  user_share_2018  
gsort - sector_order
export excel using "$results\fact3.xlsx",  sheetreplace firstrow(variables) sheet("fact3a_bounds_weighted")

restore 
}
cap log close 

