capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\fact4_`date'.log, replace
*-------------------------------------------------------------------------------
* FACT 4
*-------------------------------------------------------------------------------
cap est clear
cap est store clear
cd "$results\"
use "$data\panel_v7_rbtadopt.dta", clear										

*-------------------------------------------------------------------------------
{ // TABLE 3: DIFFERENCES BETWEEN ROBOT USERS AND NON-USERS (EXTENSIVE MARGIN)
*-------------------------------------------------------------------------------
cap est clear
cap est store clear
drop if year==2019
tab D_robot D_robot_adoption if year==2018

xtset idnum year
xtdescribe
qui xi  i.year i.bula i.wz08_2d, prefix(_)


cap est store clear
cap eststo clear
local explanatory "log_ges_bes log_busi_vol log_lprod lntfp_tv_cd log_wage highskill x05f x05c D_minwage_w66a D_export D_tech D_foreign_owner D_competition D_betrrat inno4 inno1 log_invest  "
estpost tabstat `explanatory' if year==2018 & hrf_robot!=. & D_robot!=. , stats(mean sd N) columns(stats)
est store summ2018
estpost tabstat `explanatory' if year==2014 & D_robot!=. , stats(mean sd N) columns(stats)
est store summ2014

esttab summ2018 using "summ_stats.tex", replace  ///
			cells(" mean (fmt(%9.2f)) sd(fmt(%9.2f)) count(fmt(%9.0f))") eqlabels(`e(labels)') ///
			label nostar noobs addn("Notes:") nonumbers  not ty nodepvars ///
			nomti title("Summary Statistics.")  alignment(lrrr) compress 
esttab summ2014 using "summ_stats.tex", append ///
		cells(" mean (fmt(%9.2f)) sd(fmt(%9.2f)) count(fmt(%9.0f))") eqlabels(`e(labels)') ///
		label nostar noobs addn("Notes:") nonumbers  not ty nodepvars  ///
		mtitle("Summary Statistics 2014")  alignment(lrrr) compress 


keep if year==2018
xtset idnum year 
* check for singleton observation (tfp regression manufacturing had missing SE):
tabstat lntfp_tv_cd if manuf==1 & D_robot!=. & lntfp_tv_cd!=., by(wz08_2d) stats(N)
gen help_tfp_SE=1 if lntfp_tv_cd!=. &  inlist(wz08_2d, 1, 8, 56, 66, 70, 73, 74, 77, 81, 84, 90, 94)

cap est clear
cap est store clear
* only plant size 
foreach size in log_ges_bes log_lprod {	
	* FULL, no control 
	reghdfe  `size' D_robot, vce(cluster wz08_3d) noabsorb
		est store A_`size'
		unique idnum if e(sample) & D_robot==1  
		estadd scalar Robot_N= r(N)

	* FULL + FE
	reghdfe  `size' D_robot _wz08_2d_* _bula_*  , vce(cluster wz08_3d) noabsorb
		est store B_`size'
		unique idnum if e(sample) & D_robot==1  
		estadd scalar Robot_N= r(N)
	* Manuf + FE 
	reghdfe  `size' D_robot _wz08_2d_* _bula_*  if manuf==1  , vce(cluster wz08_3d) noabsorb
		est store Am_`size'
		unique idnum if e(sample) & D_robot==1  
		estadd scalar Robot_N= r(N)
	* Non-Manuf + FE 
	reghdfe  `size' D_robot _wz08_2d_* _bula_*  if manuf==0  , vce(cluster wz08_3d) noabsorb
		est store Anm_`size'
		unique idnum if e(sample) & D_robot==1  
		estadd scalar Robot_N= r(N)
}

local size "log_ges_bes"
local explanatory2 "log_lprod lntfp_tv_cd highskill log_wage D_export  D_tech inno1 inno4 log_invest "
// D_betrrat D_tarif  D_foreign_owner D_competition   empl_older_pc  D_lscarcity D_lscarcity_hs need_staff  bluecoll_wanted vac_qualtasks"
foreach x in `explanatory2' {
	* FULL, no control 
	reghdfe  `x' D_robot , vce(cluster wz08_3d) noabsorb
		est store A_`x'
		unique idnum if e(sample) & D_robot==1  
		estadd scalar Robot_N= r(N)
	* FULL + FE
	reghdfe  `x' D_robot _wz08_2d_* _bula_* ,  vce(cluster wz08_3d) noabsorb
		est store B_`x'
		unique idnum if e(sample) & D_robot==1  
		estadd scalar Robot_N= r(N)
	* FULL + FE + size
	reghdfe  `x' D_robot `size' _wz08_2d_* _bula_* ,  vce(cluster wz08_3d) noabsorb
		est store C_`x'
		unique idnum if e(sample) & D_robot==1  
		estadd scalar Robot_N= r(N)
	* Manuf + FE + size 
	reghdfe  `x' D_robot `size' _wz08_2d_* _bula_*  if manuf==1 ,  vce(cluster wz08_3d) noabsorb
		est store D_`x'
		unique idnum if e(sample) & D_robot==1  
		estadd scalar Robot_N= r(N)
	* Non-Manuf + FE + size 
	reghdfe  `x' D_robot `size' _wz08_2d_* _bula_*  if manuf==0 ,  vce(cluster wz08_3d) noabsorb
		est store E_`x'
		unique idnum if e(sample) & D_robot==1  
		estadd scalar Robot_N= r(N)
		}
	* special regression for tfp in manufacturing, excluding singletons
	reghdfe  lntfp_tv_cd D_robot `size' _wz08_2d_* _bula_*  if manuf==1 & help_tfp_SE!=1,  vce(cluster wz08_3d) noabsorb
		est store D_lntfp_tv_cd
		
xml_tab A_*, stats(N r2_a Robot_N)  stars(0.01 0.05 0.1) drop(o.* _wz08_2d_* _bula*) note(" Pooled OLS regression for full sample in 2018 (unweighted). Robust standard errors clustered at 3digit NACE2. ") below ///
sheet("table_3_ext_full_nocontrol") save( "$results/fact4") replace
xml_tab B_*, stats(N r2_a Robot_N)  stars(0.01 0.05 0.1) drop(o.* _wz08_2d_* _bula*) note(" Pooled OLS regression for full sample with explanatory variables from 2018 (unweighted). Region (federal states) and sector dummies (wz08_2d) are included. Robust standard errors clustered at 3digit NACE2.") below ///
sheet("table_3_ext_full_FE") save( "$results/fact4") append
xml_tab B_log_ges_bes B_log_lprod C_*, stats(N r2_a Robot_N)  stars(0.01 0.05 0.1) drop(o.* _wz08_2d* _bula*  ) note(" Pooled OLS regression for full sample with explanatory variables from 2018 (unweighted). Controlled for plant size (by log totoal employment number). Region (federal states) and sector dummies (wz08_2d) are included. Robust standard errors clustered at 3digit NACE2.") below ///
sheet("table_3_ext_full_FE_size") save( "$results/fact4") append	
xml_tab Am_log_ges_bes Am_log_lprod D_*, stats(N r2_a Robot_N)  stars(0.01 0.05 0.1) drop(o.* _wz08_2d_* _bula*) note(" Pooled OLS regression for manufacturing sample in 2018. weighted. Robust standard errors clustered at 3digit NACE2.") below ///
sheet("table_3_ext_manuf_FE_size") save( "$results/fact4") append 
xml_tab Anm_log_ges_bes Anm_log_lprod E_*, stats(N r2_a Robot_N)  stars(0.01 0.05 0.1) drop(o.* _wz08_2d_* _bula*) note(" Pooled OLS regression for nonmanufacturing sample with explanatory variables from 2018 (weighted). Region (federal states) and sector dummies (wz08_2d) are included. Robust standard errors clustered at 3digit NACE2.") below ///
sheet("table_3_ext_nonmanuf_FE_size") save( "$results/fact4") append  
}

*------------------------------------------------------------------------------------------------------------------
{ // TABLE A1: DIFFERENCES BETWEEN ROBOT USERS AND NON-USERS (INTENSIVE MARGIN: LOG ROBOTS and LOG ROBOT DENSITY)
*------------------------------------------------------------------------------------------------------------------
cap est clear
cap est store clear
gen robot_intensity= robots*1000/ges_bes
gen log_robot_intensity= log(robot_intensity)
local explanatory2 "log_lprod lntfp_tv_cd highskill log_wage D_export" //  D_tech inno1 inno4 log_invest "
local size "log_ges_bes"
foreach robots in log_robots  {  //log_robot_intensity
foreach size in log_ges_bes log_lprod {
	* FULL, no control 
	reghdfe  `size' `robots', vce(cluster wz08_3d) noabsorb
		est store A_`size'
		unique idnum if e(sample) & `robots'>0 & `robots'<.
		estadd scalar Robot_N= r(N)

	* FULL + FE
	reghdfe  `size' `robots' _wz08_2d_* _bula_*  , vce(cluster wz08_3d) noabsorb
		est store B_`size'
		unique idnum if e(sample) & `robots'>0 & `robots'<.
		estadd scalar Robot_N= r(N)
}
local size "log_ges_bes"
foreach x in `explanatory2' {
	* FULL, nocontrol
	reghdfe  `x' `robots' ,  vce(cluster wz08_3d) noabsorb
		est store A_`x'
		unique idnum if e(sample) & `robots'>0 & `robots'<.
		estadd scalar Robot_N= r(N)
	* FULL + FE
	reghdfe  `x' `robots' _wz08_2d_* _bula_* ,  vce(cluster wz08_3d) noabsorb
		est store B_`x'
		unique idnum if e(sample) &`robots'>0 & `robots'<.  
		estadd scalar Robot_N= r(N)
	* FULL + FE + size
	reghdfe  `x' `robots' `size' _wz08_2d_* _bula_* ,  vce(cluster wz08_3d) noabsorb
		est store C_`x'
		unique idnum if e(sample) & `robots'>0 & `robots'<.
		estadd scalar Robot_N= r(N)
	}

xml_tab A_*, stats(N r2_a Robot_N)  stars(0.01 0.05 0.1) note(" Pooled OLS regression for `robots' based on full sample in 2018 (unweighted). Robust standard errors clustered at 3digit NACE2.") below ///
sheet("table_A1_int_full_nocontrol") save( "$results/fact4") append
xml_tab B_*, stats(N r2_a Robot_N)  stars(0.01 0.05 0.1) drop(o.* _wz08_2d_* _bula*) note(" Pooled OLS regression for `robots' based on full sample with explanatory variables from 2018 (unweighted). Region (federal states) and sector dummies (wz08_2d) are included. Robust standard errors clustered at 3digit NACE2.") below ///
sheet("table_A1_int_full_FE") save( "$results/fact4") append
xml_tab B_log_ges_bes B_log_lprod C_*, stats(N r2_a Robot_N)  stars(0.01 0.05 0.1) drop(o.* _wz08_2d_* _bula*  ) note(" Pooled OLS regression for `robots' based on full sample with explanatory variables from 2018 (unweighted). Controlled for plant size (by log totoal employment number). Region (federal states) and sector dummies (wz08_2d) are included. Robust standard errors clustered at 3digit NACE2.") below ///
sheet("table_A1_int_full_size") save( "$results/fact4") append
}
}

cap log close 
