capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\fact5_`date'.log, replace
*-------------------------------------------------------------------------------
* FACT 5
*-------------------------------------------------------------------------------
use "$data\panel_v6_rbtadopt.dta", clear										
*-------------------------------------------------------------------------------
{ // DATA PREPARATION 
*-------------------------------------------------------------------------------
*NOTE: we did a secondary survey on plants with implausible answers
*due to that one plant reduced #robots from 2 to 1
*this leads to new inconsistent answers in cage_robot question --> Corrected here 
*replace cage_robots=1 if idnum==*****	// replication version
replace cage_robots=1 if idnum==79077  // JS version

xtset idnum year 
cap est store clear
cap est clear
tab D_robot_yearly if year==2018,m
keep if D_robot!=. 	// drop observations if robot question was not answered (less than 1% is dropped)
keep if D_robot_yearly!=. 	// drop observations if 
keep if year==2018 // only for these we have informtaion on heterogeneity. 

*-------------------------------------------------------------------------------
* descriptives in text
preserve
gen expensive_robots=robots-cheap_robots if robots!=. & cheap_robots!=.
	gen share_expensive=expensive_robots/robots if D_robot_yearly==1 & expensive_robots!=.
	gen share_cage=cage_robots/robots if D_robot_yearly==1 & cage_robots!=.


* out of all robot using plants 
gen D_cage=(cage_robots>0 & !mi(cage_robots) & D_robot_yearly==1)
replace D_cage=. if D_robot_yearly==0  
codebook D_cage
tab D_cage					// 69%  
tab D_cage [aw=hrf_robot]   // 49%

* out of all robot using plants 
gen D_expensive=(expensive_robots>0 & !mi(expensive_robots) & D_robot_yearly==1)
replace D_expensive=. if D_robot_yearly==0 
tab D_expensive 				// 62% 
tab D_expensive [aw=hrf_robot]  // 53% 

* how many cage robot users have all robots as cage robots? 
tabstat D_cage if robots==cage_robots [w=hrf_robot], stats(N sum) // & cage_robots!=. 
tabstat D_cage if robots==cage_robots & cage_robots!=. [w=hrf_robot], stats(N sum) // corrected!
tabstat D_cage if  cage_robots!=. [w=hrf_robot], stats(N sum) //
di 451/532  // .85 -> as in paper but mistake! missing cage robots not counted correctly
di 15052.59/16061.44 // .93718807 -> 94!! 


* how many cage robot users have all robots as expensive robots? 
tabstat D_expensive if robots==expensive_robots & expensive_robots!=. [aw=hrf_robot], stats(N sum)  
tabstat D_expensive if expensive_robots!=. [aw=hrf_robot], stats(N sum)
di 13734.72/17250.51 // .79619211 -> 80% if weighted, but we use unweighted here
di 383/515  // .74368932 -> 75% unweighted -> correct this in paper!


* how many cage and expensive robots in relation to ALL robots in 2018 (weighted)?
tabstat robots if robots>=1 & robots<. [weight=hrf_robot], stats(N sum ) columns (statistics)
tabstat cage_robots if cage_robots>=1 & cage_robots<. [weight=hrf_robot], stats(N sum )
tabstat expensive_robots if expensive_robots>=1 & expensive_robots<. [weight=hrf_robot], stats(N sum )
di 78387.19/108665.7 // 72 %
di 48810.33/108665.7 // 45 % 


restore 
*-------------------------------------------------------------------------------
unique idnum 

* check missings in 2018 robot stock for plants that answered the extensive margin with "yes":
tab D_robot_yearly if year==2018 & D_robot==1,m
* how do we want to treat the 3 robot users that report zero robots in 2018?

// NOTE: to keep fact 5 intensive and extensive margin comparable, we do not assume D_robot_yearly=1 in 2018 as in other facts.  // VP 14/7/2022
// instead we keep the original reported stocks for Q78-Q89
replace D_robot_yearly=. if D_robot_yearly==1 & robots==. & year==2018			
tab D_robot_yearly if year==2018 & D_robot==1,m

keep if D_robot_yearly!=.
*keep if robots!=.
gen expensive_robots=robots-cheap_robots if robots!=. & cheap_robots!=.
* generate dummy for information on cage and expensive robots 
	gen D_cage_robot=1 if D_robot_yearly==1 & cage_robots==robots & cage_robots!=.	// if all robots are cage robots -> cage robot using plant.
	replace D_cage_robot=0 if D_robot_yearly==1 & (cage_robots<robots | cage_robots==0 ) & cage_robots!=.  // if some robots are cage robots -> non cage robot using plant.
	replace D_cage_robot=0 if D_robot_yearly==0												// non-robot user -> non cage robot user.
* checks 
	tab D_cage_robot if D_robot_yearly!=. & cage_robots==robots & cage_robots!=.	
	tab D_cage_robot if D_robot_yearly==1 & (cage_robots<robots | cage_robots==0 ) & cage_robots!=.
	tab D_cage_robot if D_robot_yearly==1 & (cage_robots<robots | cage_robots==0 | cage_robots==.)  
	tab D_cage_robot // 391 cage robot users 
	
	gen D_expensive_robot=1 if D_robot_yearly==1 & expensive_robots==robots & expensive_robots!=.
	replace D_expensive_robot=0 if D_robot_yearly==1 & (expensive_robots<robots | expensive_robots==0) & expensive_robots!=.
	replace D_expensive_robot=0 if D_robot_yearly==0
	tab D_expensive_robot	// 323 expensive robot users 
	
	gen D_neither=1 if (D_robot_yearly==1 & D_expensive_robot!=1 & D_cage_robot!=1) 
	replace D_neither=0 if D_expensive_robot==1 | D_cage_robot==1 | D_robot_yearly==0
	tab D_neither
	tab D_robot_yearly if D_cage_robot==1 & D_expensive_robot==1 & D_robot_yearly==1 &robots!=. 
	tab  D_cage_robot D_expensive_robot 
	tab  D_cage_robot D_expensive_robot if robots!=. &cage_robots!=. & expensive_robots!=.
	
* intensive margin measures: share of expensive robots and share of cage robots
	cap drop expensive_robots 
	gen expensive_robots= robots-cheap_robots if D_robot_yearly==1 & cheap_robots!=.
	gen share_expensive=expensive_robots/robots if D_robot_yearly==1 & expensive_robots!=.
	gen share_cage=cage_robots/robots if D_robot_yearly==1 & cage_robots!=.

* table notes
tab D_cage_robot
tab D_expensive_robot
tab D_neither		// 167 are neither state use of cage or expensive robots.
tabstat D_neither if D_robot_yearly==1 , stats(mean N sum )
tabstat D_neither if D_robot_yearly==1 [weight=hrf_robot], stats(mean N sum )

* cage robots and all robots are similarily distributed across manuf and non-manuf.
tabstat cage_robots robots ,  stats(mean sum  N)	
tabstat cage_robots [weight=hrf_robot],  stats(sum)	
tabstat cage_robots [weight=hrf_robot],  stats(sum)	by(manuf)
	
qui xi  i.year i.IAB_43 i.bula i.wz08_2d, prefix(_)
}


*-------------------------------------------------------------------------------
{ // HETEROGENEITY OF ROBOT USE  (EXTENSIVE MARGIN) 
*-------------------------------------------------------------------------------
/* Take the 2018 sample. Regression (1) using both robot users and non-users:

(1a) Plant Characteristic = \alpha + \beta D_expensive_robot_User + \gamma D_cage_robot_User + Fixed Effects
(1b)  Plant Characteristic = \alpha + \beta D_expensive_robot_User + \gamma D_cage_robot_User + Plant Size Control + Fixed Effects

Do those regressions with and without weights.

Regression (2) using only robot users:

(2a) Plant Characteristic = \alpha + \beta D_cage D_expensive_robot D_cage_robot D_neither + Fixed Effects
(2b)  Plant Characteristic = \alpha + \beta D_cage D_expensive_robot D_cage_robot D_neither + Plant Size Control + Fixed Effects

*/

cap est clear
cap est store clear
local ind "wz08_2d"
local size "log_ges_bes"
	reghdfe `size' D_cage_robot D_expensive_robot D_robot_yearly _wz08_2d_* _bula_* , vce(cluster wz08_3d) noabsorb
		est store A1_`size'		
		unique idnum if e(sample) & D_cage_robot==1  
		return list
		estadd scalar Cage_N= r(N)
		unique idnum if e(sample) & D_expensive_robot==1  
		estadd scalar Expensive_N= r(N)
		unique idnum if e(sample) & D_expensive_robot==1  & D_cage==0  
		estadd scalar Exp_noncage_N= r(N)
		unique idnum if e(sample) & D_robot_yearly==1  
		estadd scalar Robot_N= r(N)
local explanatory "log_lprod lntfp_tv_cd highskill log_wage D_export" //  D_tech inno1 inno4 log_invest "
foreach x in `explanatory' {
	reghdfe `x' D_cage_robot D_expensive_robot D_robot_yearly log_ges_bes _wz08_2d_* _bula_* ,   vce(cluster wz08_3d) noabsorb
		est store B1_`x'
		unique idnum if e(sample) & D_cage_robot==1  
		estadd scalar Cage_N= r(N)
		unique idnum if e(sample) & D_expensive_robot==1  
		estadd scalar Expensive_N= r(N)
		unique idnum if e(sample) & D_expensive_robot==1  & D_cage==0  
		estadd scalar Exp_noncage_N= r(N)
		unique idnum if e(sample) & D_robot_yearly==1  
		estadd scalar Robot_N= r(N)
		}
xml_tab A1_* B1_*, stats(N r2_a Cage_N Expensive_N Exp_noncage_N Robot_N) drop(o.* _wz08_2d_* _bula* )  stars(0.01 0.05 0.1) note("Pooled OLS regression on full sample with explanatory variables from 2018 (unweighted). Region (federal states) and sector dummies (`ind') are included. Controlled for plant size (by log totoal employment number) for all columns, except the first. Robust standard errors clustered at 3digit NACE 2. ") ///
below sheet("table5_ext_full_size") save( "$results/fact5") replace
}

*-------------------------------------------------------------------------------
{ // HETEROGENEITY OF ROBOT USE  (INTENSIVE MARGIN) 
*-------------------------------------------------------------------------------
/* Take the 2018 sample. Regression (3) using only robot users:

(3)  Plant Characteristic = \alpha + \beta share_cage_robots + \gamma share_cheap_robots + robot number control + Plant Size Control + Fixed Effects
Do those regressions with and without weights.
*/
preserve 
keep if D_robot_yearly!=.

reghdfe `size' log_robots share_cage share_expensive  _wz08_2d_* _bula_* if D_robot_yearly==1 ,   vce(cluster wz08_3d) noabsorb
		est store C1_`size'

local explanatory "log_lprod lntfp_tv_cd highskill log_wage D_export" //  D_tech inno1 inno4 log_invest "
foreach x in `explanatory' {
	reghdfe `x' log_robots share_cage share_expensive  log_ges_bes _wz08_2d_* _bula_* ,   vce(cluster wz08_3d) noabsorb
		est store C2_`x'
		}


xml_tab C1_`size' C2_*, stats(N r2_a)  drop( o.* _wz08_2d_* _bula*)  stars(0.01 0.05 0.1) note(" Pooled OLS regression on robot user sample in 2018.  Region (federal states) and sector dummies (`ind') are included. Controlled for plant size (by log totoal employment number) for all columns, except the first.  Robust standard errors clustered at 3digit NACE 2. ") below ///
sheet("table_A2_int_full_size") save( "$results/fact5") append

restore 
}

cap log close 




