capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\regression_choice_explanatories_`date'.log, replace
*-------------------------------------------------------------------------------
* TABLE 5
*-------------------------------------------------------------------------------
cap est clear
cap est store clear
cd "$results\"
use "$data\panel_v6_rbtadopt.dta", clear										

*-------------------------------------------------------------------------------
{ // DATA PREPARATION 
*-------------------------------------------------------------------------------
tab D_robot_yearly year 
drop if D_robot==1 & D_robot_adoption==0		// drop robot users, they do not have a adoption decision to make

xtset idnum year
xtdescribe

*** CREATE BASE YEAR VARIABLES:
local vars "log_ges_bes log_busi_vol log_lprod lntfp_tv_cd highskill log_wage D_minwage_w66a D_export D_foreign_owner x05f x05c D_betrrat  D_tarif inno4 inno1 log_invest D_lscarcity D_lscarcity_hs" 

foreach x in `vars' {
		sort idnum year
		by idnum: gen `x'_base=`x' if year==2014	
		cap drop junk 
		by idnum: egen junk=min(`x'_base) 
		by idnum: replace `x'_base= junk if `x'_base==.
		}
qui xi i.IAB_43 i.bula   i.wz08_2d, prefix(_)
}

*-------------------------------------------------------------------------------
{ // TABLE 5 (CROSS SECTIONAL in 2018 with base year explanatories) 
*-------------------------------------------------------------------------------
xtset idnum year 
local explanatory "lntfp_tv_cd highskill log_wage D_minwage_w66a D_export D_foreign_owner x05f x05c D_betrrat  inno4 inno1 log_invest D_tarif D_lscarcity" 

* Version F: full sample, industry dummies and regional dummies, control for plant size
cap est clear
cap est store clear
* only size measures
	reghdfe D_robot_adoption  log_lprod_base _wz08_*  _bula_*  if year==2018 ,  vce(cluster wz08_3d) noabsorb
		est store F_prod
	reghdfe D_robot_adoption  log_ges_bes_base _wz08_*  _bula_*  if year==2018 ,  vce(cluster wz08_3d) noabsorb
		est store F_empl
		* explanatories with size control
foreach x in `explanatory' {
	reghdfe D_robot_adoption `x'_base log_ges_bes_base _wz08_*  _bula_*  if year==2018 ,  vce(cluster wz08_3d) noabsorb
		est store F_`x'
		}

* output:
xml_tab F_*, stats(N r2_a)  stars(0.01 0.05 0.1) drop(o.* _wz08_* _bula*) note("Dependent variable is robot adoption. Pooled OLS regression for full sample with explanatory variables from base year 2014. `e(cmdline)'.") below ///
sheet("1F_full") save( "$results/results_table_5") replace

*-------------------------------------------------------------------------------
// ROBUSTNESS CHECKS
* include log_busi_vol_base instead of employment 
* for manufacturing vs non manufacturing include additional if-condition in regression commands (if manuf==0 or if manuf==1)
*-------------------------------------------------------------------------------
}
cap log close 

