capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\regression_crossection_`date'.log, replace
*-------------------------------------------------------------------------------
* TABLE 6
*-------------------------------------------------------------------------------
cap est clear
cap est store clear
cd "$results\"
use "$data\panel_v6_rbtadopt.dta", clear										

*---------------------*
{ // DATA PREPARATION *
*---------------------*
drop if D_robot==1 & D_robot_adoption==0		// drop robot users, they do not have a adoption decision to make

xtset idnum year
xtdescribe

*** CREATE BASE YEAR VARIABLES:
local vars "log_ges_bes log_busi_vol log_lprod lntfp_tv_cd highskill log_wage D_minwage_w66a D_export D_foreign_owner D_betrrat  D_tarif D_tech D_competition inno4 inno1 log_invest " 
local vars2 "x05f x05c" 
global baseyear "2014" 

foreach x in `vars' {
		sort idnum year
		by idnum: gen `x'_base=`x' if year==${baseyear}	
		cap drop junk 
		by idnum: egen junk=min(`x'_base) 
		by idnum: replace `x'_base= junk if `x'_base==.
		}

foreach x in `vars2' {
		sort idnum year
		by idnum: gen `x'_base=`x' if year==2014	
		cap drop junk 
		by idnum: egen junk=min(`x'_base) 
		by idnum: replace `x'_base= junk if `x'_base==.
		}

keep if year==2018 // only for this cross sectional setting below, where all explanatories from 2014 are saved in separate varibale.
qui xi i.IAB_43 i.bula i.wz08_2d  , prefix(_) //
}

*-------------------------------------------------------------------------------
{ // TABLE 6
*-------------------------------------------------------------------------------
local b "highskill_base"
local c "D_minwage_w66a_base"
local d "D_export_base"
local e "x05f_base"   
local f "x05c_base"   
local g "D_betrrat_base"
local h "D_tech_base"
local i "inno4_base"
local j "D_competition_base"
local k "D_foreign_owner_base"

local ind "wz08_2d"
local reg "bula"
local size "log_ges_bes_base " 	// include here other size measures log_busi_vol_base 

* create file:
qui reghdfe D_robot_adoption _`ind'_* _`reg'_* ,  vce(robust) noabsorb 
		est store test

xml_tab test  , stats(N r2)  stars(0.01 0.05 0.1)  drop(o.* *`ind'* *`reg'* *wz08_2d*)  note(" OLS regression for full sample with explanatory variables from base year ${baseyear}, controlled for employment count. Region (federal states) and sector dummies (`ind') are included. Robust standard errors. Last column is robustness check with wz08 industry classification.") below sheet("test") save( "$results/results_table_6") replace

{ //  regressions
foreach size in `size' {
cap est clear
cap est store clear
**** FULL SAMPLE:
	reghdfe D_robot_adoption `size'  `b' `c' `d' `e' `f'  ///
		_`ind'_* _`reg'_* ,  vce(cluster wz08_3d) noabsorb 
		est store B1a_full
	reghdfe D_robot_adoption `size'  `b' `c' `d' `e' `f' `g' `h' `i' `j' `k'  ///
		_`ind'_* _`reg'_* ,  vce(cluster wz08_3d) noabsorb 
		est store B1b_full
**** MANUFACTURING:
	reghdfe D_robot_adoption `size'  `b' `c' `d' `e' `f'  ///
		_`ind'_* _`reg'_* if manuf==1,  vce(cluster wz08_3d) noabsorb 
		est store B1a_m
	reghdfe D_robot_adoption `size'  `b' `c' `d' `e' `f' `g' `h' `i' `j' `k'   ///
		_`ind'_* _`reg'_* if manuf==1,  vce(cluster wz08_3d) noabsorb 
		est store B1b_m
**** NONMANUFACTURING:
	reghdfe D_robot_adoption `size'  `b' `c' `d' `e' `f'  ///
		_`ind'_* _`reg'_* if manuf==0,  vce(cluster wz08_3d) noabsorb 
		est store B1a_nm
	reghdfe D_robot_adoption `size'  `b' `c' `d' `e' `f' `g' `h' `i' `j' `k'   ///
		_`ind'_* _`reg'_* if manuf==0,  vce(cluster wz08_3d) noabsorb 
		est store B1b_nm
}
xml_tab B1*    , stats(N r2)  stars(0.01 0.05 0.1)  drop(o.* *`ind'* *`reg'* *wz08_2d*)  note(" ") below sheet("table_6_empl_clustered_SE_3d") save( "$results/results_table_6") replace
}
}
*------------------------------------------------------------------------------*
cap log close

