capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\regression_analysis_2windows_`date'.log, replace
*-------------------------------------------------------------------------------
* TABLE 7
/*-------------------------------------------------------------------------------
* 2 WINDOWS OF ADOPTION, EXPLANATORIES FROM BASE YEAR 2014 or 2016 respectively:
	To increase size of control group and include time effect for adopters we use 
	2 windows for robot adoption (2015-2016 is window 1 and 2017-2018 is window 2). 
	The first group of adopters is compared to controlgroup in first window (explanatories from 2014).
	The second group of adopters is compared to controlgroup in second window (explanatories from 2016).
*------------------------------------------------------------------------------*/
cap est store clear 
cap est clear
cd "$results\"
use "$data\panel_v6_rbtadopt.dta", clear										
xtset idnum year

*-------------------------------------------------------------------------------
{ // DATA PREPARATION 
*-------------------------------------------------------------------------------
drop if D_robot==1 & D_robot_adoption==0		// drop plants that are robot users in all periods, they do not have a adoption decision to make
drop if D_robot==.								// drop plants that did not answer extensive margin robot question in 2019
drop if D_robot_adoption==.						// drop plants that did not answer the intensive robot survey questions in 2019
tab D_windows D_robot_adoption

xtset idnum year
xtdescribe
cap drop help
bys idnum: egen help=min(D_windows)
bys idnum: replace D_windows=help if D_windows==.

*** CREATE BASE YEAR VARIABLES:
local vars "D_minwage_w66a log_ges_bes log_busi_vol highskill D_export D_tech D_foreign_owner log_wage D_competition D_betrrat D_tarif inno4 inno1 log_lprod x05f x05c log_invest lntfp_tv_cd  "

foreach x in `vars' {
		bys idnum: gen `x'_base=`x' if year==2014	
		cap drop help
		bys idnum: egen help=min(`x'_base)
		bys idnum: replace `x'_base=help if `x'_base==.
		bys idnum: gen `x'_base_2016=`x' if year==2016
		cap drop help
		bys idnum: egen help=min(`x'_base_2016)
		bys idnum: replace `x'_base_2016=help if `x'_base_2016==.
		
		drop *base_2016
		}
keep if year==2014 | year==2016

*group industry year and region year for FE:
egen indXyear = group(IAB_43 year)
gen wz082d_dupli=wz08_2d
egen wz2dXyear = group(wz082d_dupli year)
egen regXyear = group(bula year)

* create dummies:		
qui xi  i.regXyear  i.indXyear  i.wz2dXyear, prefix(_)
* so far, the robot adoption information exists 2 times in panel. 
* As the time effect will be captured by the window dummy, we delete duplicates:
drop if year==2014 & D_windows==2 & D_robot_adoption==1
drop if year==2016 & D_windows==1 & D_robot_adoption==1
}

*-------------------------------------------------------------------------------
{ // TABLE 7
*-------------------------------------------------------------------------------
local b "highskill_base"
local c "D_minwage_w66a_base"
local d "D_export_base"
local e "x05f_base"   
local f "x05c_base"   
local g "D_betrrat_base"
local h "D_tech_base"
local i "inno4_base"
local j "D_competition_base"
local k "D_foreign_owner_base"

local reg "regXyear"
local ind "wz2dXyear"
local clustvar "idnum" // idnum if no clustering wanted 


local size "log_ges_bes_base " // include here BHP size measures log_busi_vol_base log_az_ges_base

**** FULL
	reghdfe D_robot_adoption D_windows  `size' `b' `c' `d' `e' `f'  ///
		_`ind'_* _`reg'_* ,   vce(cluster idnum)  noabsorb
		est store r_1
	reghdfe D_robot_adoption D_windows  `size' `b' `c' `d' `e' `f' `g' `h' `i' `j' `k'  ///
		_`ind'_* _`reg'_* ,   vce(cluster idnum)  noabsorb
		est store r_2
**** MANUFACTURING:
	reghdfe D_robot_adoption D_windows  `size' `b' `c' `d' `e' `f'  ///
		_`ind'_* _`reg'_* if manuf==1,   vce(cluster idnum)  noabsorb
		est store r_1m
	reghdfe D_robot_adoption D_windows  `size' `b' `c' `d' `e' `f' `g' `h' `i' `j' `k'  ///
		_`ind'_* _`reg'_* if manuf==1,   vce(cluster idnum)  noabsorb
		est store r_2m
**** NONMANUFACTURING:
	reghdfe D_robot_adoption D_windows  `size' `b' `c' `d' `e' `f'  ///
		_`ind'_* _`reg'_* if manuf==0,   vce(cluster idnum)  noabsorb
		est store r_1nm
	reghdfe D_robot_adoption D_windows  `size' `b' `c' `d' `e' `f' `g' `h' `i' `j' `k'  ///
		_`ind'_* _`reg'_* if manuf==0,   vce(cluster idnum)  noabsorb
		est store r_2nm
		
xml_tab r_* , stats(N r2)  stars(0.01 0.05 0.1) drop(o.* *`ind'* *`reg'* *wz08_2d*) note("OLS regression for 2 windows of robot adoption (2015-2016) and (2017-2018) with explanatory variables from base year 2014/2016, controlled for employment count. Region-year (`reg') and sector-year dummies are included (`ind'). Robust standard errors are clustered at plant level.") below sheet("2windows_full_empl") save( "$results/results_table_7") cn("full" "full" "manuf" "manuf" "non-manuf" "non-manuf") replace
}

cap log close
